@@ -1,10 +1,7 @@
 $(function() {
 	$("#my-favs ul").sortable({'cursor':'move'});
-	$("#my-favs ul").hover(function () {
-		$(this).css({'cursor':'move'});
-	}, function () {
-		$(this).css({'cursor':'auto'});
-	});
+	$("#my-favs ul, #my-favs ul *").css({'cursor':'move'});
+	$("#my-favs ul input").css({'cursor':'auto'});
 	$('#favs-form').submit(function() {
 		var order=[];
 		$("#my-favs ul li input.position").each(function() {
@@ -14,4 +11,4 @@ $(function() {
 		return true;
 	});
 	$("#my-favs ul li input.position").hide();
-});
\ No newline at end of file
+});
