@@ -1,7 +1,11 @@
 $(function() {
+	var reset_url = '?';
+	if (dotclear.filter_reset_url != undefined) {
+		reset_url = dotclear.filter_reset_url;
+	}
 
 	$filtersform = $('#filters-form');
-	$filtersform.before('<p><a id="filter-control" class="form-control" href="?" style="display:inline">'+dotclear.msg.filter_posts_list+'</a></p>')
+	$filtersform.before('<p><a id="filter-control" class="form-control" href="'+reset_url+'" style="display:inline">'+dotclear.msg.filter_posts_list+'</a></p>')
 
 	if( dotclear.msg.show_filters == 'false' ) {
 		$filtersform.hide();
