@@ -16,7 +16,7 @@ dcPage::check('media,media_admin');
 
 $tab = empty($_REQUEST['tab']) ? '' : $_REQUEST['tab'];
 
-$post_id = !empty($_GET['post_id']) ? (integer) $_GET['post_id'] : null;
+$post_id = !empty($_REQUEST['post_id']) ? (integer) $_REQUEST['post_id'] : null;
 if ($post_id) {
 	$post = $core->blog->getPosts(array('post_id'=>$post_id));
 	if ($post->isEmpty()) {
@@ -27,12 +27,22 @@ if ($post_id) {
 }
 
 $file = null;
-$popup = (integer) !empty($_GET['popup']);
-$page_url = 'media_item.php?popup='.$popup.'&post_id='.$post_id;
-$media_page_url = 'media.php?popup='.$popup.'&post_id='.$post_id;
+$popup = (integer) !empty($_REQUEST['popup']);
+$plugin_id = isset($_REQUEST['plugin_id']) ? html::sanitizeURL($_REQUEST['plugin_id']) : '';
+$page_url_params = array('popup' => $popup,'post_id' => $post_id);
+$media_page_url_params = array('popup' => $popup,'post_id' => $post_id);
+
+if ($plugin_id != '') {
+	$page_url_params['plugin_id'] = $plugin_id;
+	$media_page_url_params['plugin_id'] = $plugin_id;
+}
 
 $id = !empty($_REQUEST['id']) ? (integer) $_REQUEST['id'] : '';
 
+if ($id != '') {
+	$page_url_params ['id'] = $id;
+}
+
 if ($popup) {
 	$open_f = array('dcPage','openPopup');
 	$close_f = array('dcPage','closePopup');
@@ -82,7 +92,7 @@ if ($file && !empty($_FILES['upfile']) && $file->editable && $core_media_writabl
 		$core->media->uploadFile($_FILES['upfile']['tmp_name'],$file->basename,null,false,true);
 
 		dcPage::addSuccessNotice(__('File has been successfully updated.'));
-		http::redirect($page_url.'&id='.$id);
+		$core->adminurl->redirect('admin.media.item',$page_url_params);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -111,7 +121,8 @@ if ($file && !empty($_POST['media_file']) && $file->editable && $core_media_writ
 		$core->media->updateFile($file,$newFile);
 
 		dcPage::addSuccessNotice(__('File has been successfully updated.'));
-		http::redirect($page_url.'&id='.$id.'&tab=media-details-tab');
+		$page_url_params['tab'] = 'media-details-tab';
+		$core->adminurl->redirect('admin.media.item',$page_url_params);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -125,7 +136,8 @@ if (!empty($_POST['thumbs']) && $file->media_type == 'image' && $file->editable
 		$core->media->mediaFireRecreateEvent($file);
 
 		dcPage::addSuccessNotice(__('Thumbnails have been successfully updated.'));
-		http::redirect($page_url.'&id='.$id.'&tab=media-details-tab');
+		$page_url_params['tab'] = 'media-details-tab';
+		$core->adminurl->redirect('admin.media.item',$page_url_params);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -138,7 +150,8 @@ if (!empty($_POST['unzip']) && $file->type == 'application/zip' && $file->editab
 		$unzip_dir = $core->media->inflateZipFile($file,$_POST['inflate_mode'] == 'new');
 
 		dcPage::addSuccessNotice(__('Zip file has been successfully extracted.'));
-		http::redirect($media_page_url.'&d='.$unzip_dir);
+		$media_page_url_params['d'] = $unzip_dir;
+		$core->adminurl->redirect('admin.media',$media_page_url_params);
 	} catch (Exception $e) {
 		$core->error->add($e->getMessage());
 	}
@@ -163,37 +176,49 @@ if (!empty($_POST['save_blog_prefs']))
 	}
 
 	dcPage::addSuccessNotice(__('Default media insertion settings have been successfully updated.'));
-	http::redirect($page_url.'&id='.$id);
+	$core->adminurl->redirect('admin.media.item',$page_url_params);
 }
 
 # Function to get image title based on meta
-function dcGetImageTitle($file,$pattern,$dto_first=false)
+function dcGetImageTitle($file,$pattern,$dto_first=false,$no_date_alone=false)
 {
 	$res = array();
 	$pattern = preg_split('/\s*;;\s*/',$pattern);
 	$sep = ', ';
+	$dates = 0;
+	$items = 0;
 
 	foreach ($pattern as $v) {
 		if ($v == 'Title') {
 			if ($file->media_title != '') {
 				$res[] = $file->media_title;
 			}
+			$items++;
 		} elseif ($file->media_meta->{$v}) {
 			if ((string) $file->media_meta->{$v} != '') {
 				$res[] = (string) $file->media_meta->{$v};
 			}
+			$items++;
 		} elseif (preg_match('/^Date\((.+?)\)$/u',$v,$m)) {
 			if ($dto_first && ($file->media_meta->DateTimeOriginal != 0)) {
 				$res[] = dt::dt2str($m[1],(string) $file->media_meta->DateTimeOriginal);
 			} else {
 				$res[] = dt::str($m[1],$file->media_dt);
 			}
+			$items++;
+			$dates++;
 		} elseif (preg_match('/^DateTimeOriginal\((.+?)\)$/u',$v,$m) && $file->media_meta->DateTimeOriginal) {
 			$res[] = dt::dt2str($m[1],(string) $file->media_meta->DateTimeOriginal);
+			$items++;
+			$dates++;
 		} elseif (preg_match('/^separator\((.*?)\)$/u',$v,$m)) {
 			$sep = $m[1];
 		}
 	}
+	if ($no_date_alone && $dates == count($res) && $dates < $items) {
+		// On ne laisse pas les dates seules, sauf si ce sont les seuls items du pattern (hors séparateur)
+		return '';
+	}
 	return implode($sep,$res);
 }
 
@@ -206,10 +231,14 @@ $starting_scripts =
 	"//]]>".
 	"</script>".
 	dcPage::jsLoad('js/_media_item.js');
-if ($popup) {
-	$starting_scripts .=
-	dcPage::jsLoad('js/jsToolBar/popup_media.js');
+if ($popup && !empty($plugin_id)) {
+	$starting_scripts .= $core->callBehavior('adminPopupMedia', $plugin_id);
 }
+$temp_params = $media_page_url_params;
+$temp_params['d']='%s';
+$bc_template = $core->adminurl->get('admin.media',$temp_params,'&amp;',true);
+$temp_params['d']='';
+$home_url=$core->adminurl->get('admin.media',$temp_params);
 call_user_func($open_f,__('Media manager'),
 	$starting_scripts.
 	dcPage::jsDatePicker().
@@ -217,8 +246,8 @@ call_user_func($open_f,__('Media manager'),
 	dcPage::breadcrumb(
 		array(
 			html::escapeHTML($core->blog->name) => '',
-			__('Media manager') => html::escapeURL($media_page_url).'&amp;d=',
-			$core->media->breadCrumb(html::escapeURL($media_page_url).'&amp;d=%s').'<span class="page-title">'.$file->basename.'</span>' => ''
+			__('Media manager') => $home_url,
+			$core->media->breadCrumb($bc_template).'<span class="page-title">'.$file->basename.'</span>' => ''
 		),
 		array(
 			'home_link' => !$popup,
@@ -247,6 +276,9 @@ if (!empty($_GET['blogprefupd'])) {
 	dcPage::success(__('Default media insertion settings have been successfully updated.'));
 }
 
+# Get major file type (first part of mime type)
+$file_type = explode('/',$file->type);
+
 # Insertion popup
 if ($popup)
 {
@@ -272,7 +304,8 @@ if ($popup)
 		$media_type = 'image';
 		$media_desc = dcGetImageTitle($file,
 			$core->blog->settings->system->media_img_title_pattern,
-			$core->blog->settings->system->media_img_use_dto_first);
+			$core->blog->settings->system->media_img_use_dto_first,
+			$core->blog->settings->system->media_img_no_date_alone);
 		if ($media_desc == $file->basename) {
 			$media_desc = '';
 		}
@@ -322,7 +355,7 @@ if ($popup)
 		'</p>'.
 		'</div>';
 	}
-	elseif ($file->type == 'audio/mpeg3')
+	elseif ($file_type[0] == 'audio')
 	{
 		$media_type = 'mp3';
 
@@ -345,12 +378,12 @@ if ($popup)
 		}
 
 		$public_player_style = unserialize($core->blog->settings->themes->mp3player_style);
-		$public_player = dcMedia::mp3player($file->file_url,$core->blog->getQmarkURL().'pf=player_mp3.swf',$public_player_style);
+		$public_player = dcMedia::audioPlayer($file->type,$file->file_url,$core->blog->getQmarkURL().'pf=player_mp3.swf',$public_player_style);
 		echo form::hidden('public_player',html::escapeHTML($public_player));
 		echo '</p>';
 		echo '</div>';
 	}
-	elseif ($file->type == 'video/x-flv' || $file->type == 'video/mp4' || $file->type == 'video/x-m4v')
+	elseif ($file_type[0] == 'video')
 	{
 		$media_type = 'flv';
 
@@ -385,7 +418,7 @@ if ($popup)
 		}
 
 		$public_player_style = unserialize($core->blog->settings->themes->flvplayer_style);
-		$public_player = dcMedia::flvplayer($file->file_url,$core->blog->getQmarkURL().'pf=player_flv.swf',$public_player_style);
+		$public_player = dcMedia::videoPlayer($file->type,$file->file_url,$core->blog->getQmarkURL().'pf=player_flv.swf',$public_player_style);
 		echo form::hidden('public_player',html::escapeHTML($public_player));
 		echo '</p>';
 		echo '</div>';
@@ -411,13 +444,13 @@ if ($popup)
 	if ($media_type != 'default') {
 		echo
 		'<div class="border-top">'.
-		'<form id="save_settings" action="'.html::escapeURL($page_url).'" method="post">'.
+		'<form id="save_settings" action="'.$core->adminurl->getBase('admin.media.item').'" method="post">'.
 		'<p>'.__('Make current settings as default').' '.
 		'<input class="reset" type="submit" name="save_blog_prefs" value="'.__('OK').'" />'.
 		form::hidden(array('pref_src'),'').
 		form::hidden(array('pref_alignment'),'').
 		form::hidden(array('pref_insertion'),'').
-		form::hidden(array('id'),$id).
+		$core->adminurl->getHiddenFormFields('admin.media.item',$page_url_params).
 		$core->formNonce().'</p>'.
 		'</form>'.'</div>';
 	}
@@ -459,21 +492,21 @@ if ($file->media_image)
 	foreach (array_reverse($file->media_thumb) as $s => $v)
 	{
 		$strong_link = ($s == $thumb_size) ? '<strong>%s</strong>' : '%s';
-		printf($strong_link,'<a href="'.html::escapeURL($page_url).
-		'&amp;id='.$id.'&amp;size='.$s.'&amp;tab=media-details-tab">'.$core->media->thumb_sizes[$s][2].'</a> | ');
+		printf($strong_link,'<a href="'.$core->adminurl->get('admin.media.item',array_merge($page_url_params,
+			array("size" => $s,'tab' => 'media-details-tab'))).'">'.$core->media->thumb_sizes[$s][2].'</a> | ');
 	}
-	echo '<a href="'.html::escapeURL($page_url).'&amp;id='.$id.'&amp;size=o&amp;tab=media-details-tab">'.__('original').'</a>';
+	echo '<a href="'.$core->adminurl->get('admin.media.item',array_merge($page_url_params,array("size" => "o","tab"=>"media-details-tab"))).'">'.__('original').'</a>';
 	echo '</p>';
 }
 
-if ($file->type == 'audio/mpeg3')
+// Show player if relevant
+if ($file_type[0] == 'audio')
 {
-	echo dcMedia::mp3player($file->file_url,'index.php?pf=player_mp3.swf');
+	echo dcMedia::audioPlayer($file->type,$file->file_url,$core->adminurl->get("admin.home",array('pf' => 'player_mp3.swf')));
 }
-
-if ($file->type == 'video/x-flv' || $file->type == 'video/mp4' || $file->type == 'video/x-m4v')
+if ($file_type[0] == 'video')
 {
-	echo dcMedia::flvplayer($file->file_url,'index.php?pf=player_flv.swf');
+	echo dcMedia::videoPlayer($file->type,$file->file_url,$core->adminurl->get("admin.home",array('pf' => 'player_flv.swf')));
 }
 
 echo
@@ -488,7 +521,7 @@ echo
 if (empty($_GET['find_posts']))
 {
 	echo
-	'<p><a class="button" href="'.html::escapeHTML($page_url).'&amp;id='.$id.'&amp;find_posts=1&amp;tab=media-details-tab">'.
+	'<p><a class="button" href="'.$core->adminurl->get('admin.media.item',array_merge($page_url_params,array("find_posts"=>1,"tab"=>"media-details-tab"))).'">'.
 	__('Show entries containing this media').'</a></p>';
 }
 else
@@ -583,11 +616,11 @@ if ($file->editable && $core_media_writable)
 	if ($file->media_type == 'image')
 	{
 		echo
-		'<form class="clear fieldset" action="'.html::escapeURL($page_url).'" method="post">'.
+		'<form class="clear fieldset" action="'.$core->adminurl->get("admin.media.item").'" method="post">'.
 		'<h4>'.__('Update thumbnails').'</h4>'.
 		'<p>'.__('This will create or update thumbnails for this image.').'</p>'.
 		'<p><input type="submit" name="thumbs" value="'.__('Update thumbnails').'" />'.
-		form::hidden(array('id'),$id).
+		$core->adminurl->getHiddenFormFields('admin.media',$page_url_params).
 		$core->formNonce().'</p>'.
 		'</form>';
 	}
@@ -600,7 +633,7 @@ if ($file->editable && $core_media_writable)
 		);
 
 		echo
-		'<form class="clear fieldset" id="file-unzip" action="'.html::escapeURL($page_url).'" method="post">'.
+		'<form class="clear fieldset" id="file-unzip" action="'.$core->adminurl->get("admin.media.item").'" method="post">'.
 		'<h4>'.__('Extract archive').'</h4>'.
 		'<ul>'.
 		'<li><strong>'.__('Extract in a new directory').'</strong> : '.
@@ -611,13 +644,13 @@ if ($file->editable && $core_media_writable)
 		'<p><label for="inflate_mode" class="classic">'.__('Extract mode:').'</label> '.
 		form::combo('inflate_mode',$inflate_combo,'new').
 		'<input type="submit" name="unzip" value="'.__('Extract').'" />'.
-		form::hidden(array('id'),$id).
+		$core->adminurl->getHiddenFormFields('admin.media',$page_url_params).
 		$core->formNonce().'</p>'.
 		'</form>';
 	}
 
 	echo
-	'<form class="clear fieldset" action="'.html::escapeURL($page_url).'" method="post">'.
+	'<form class="clear fieldset" action="'.$core->adminurl->get("admin.media.item").'" method="post">'.
 	'<h4>'.__('Change media properties').'</h4>'.
 	'<p><label for="media_file">'.__('File name:').'</label>'.
 	form::field('media_file',30,255,html::escapeHTML($file->basename)).'</p>'.
@@ -630,12 +663,12 @@ if ($file->editable && $core_media_writable)
 	'<p><label for="media_path">'.__('New directory:').'</label>'.
 	form::combo('media_path',$dirs_combo,dirname($file->relname)).'</p>'.
 	'<p><input type="submit" accesskey="s" value="'.__('Save').'" />'.
-	form::hidden(array('id'),$id).
+	$core->adminurl->getHiddenFormFields('admin.media.item',$page_url_params).
 	$core->formNonce().'</p>'.
 	'</form>';
 
 	echo
-	'<form class="clear fieldset" action="'.html::escapeURL($page_url).'" method="post" enctype="multipart/form-data">'.
+	'<form class="clear fieldset" action="'.$core->adminurl->get("admin.media.item").'" method="post" enctype="multipart/form-data">'.
 	'<h4>'.__('Change file').'</h4>'.
 	'<div>'.form::hidden(array('MAX_FILE_SIZE'),DC_MAX_UPLOAD_SIZE).'</div>'.
 	'<p><label for="upfile">'.__('Choose a file:').
@@ -643,18 +676,17 @@ if ($file->editable && $core_media_writable)
 	'<input type="file" id="upfile" name="upfile" size="35" />'.
 	'</label></p>'.
 	'<p><input type="submit" value="'.__('Send').'" />'.
-	form::hidden(array('id'),$id).
+	$core->adminurl->getHiddenFormFields('admin.media',$page_url_params).
 	$core->formNonce().'</p>'.
 	'</form>';
 
 	if ($file->del) {
 		echo
-		'<form id="delete-form" method="post" action="'.html::escapeURL($media_page_url).
-		'&amp;d='.rawurlencode(dirname($file->relname)).
-		'&amp;remove='.rawurlencode($file->basename).'">'.
+		'<form id="delete-form" method="post" action="'.$core->adminurl->getBase("admin.media").'">'.
 		'<p><input name="delete" type="submit" class="delete" value="'.__('Delete this media').'" />'.
 		form::hidden('remove',rawurlencode($file->basename)).
 		form::hidden('rmyes',1).
+		$core->adminurl->getHiddenFormFields('admin.media',$media_page_url_params).
 		$core->formNonce().'</p>'.
 		'</form>';
 	}
