@@ -481,9 +481,9 @@ class dcTrackback
 		return null;
 	}
 
-	private static function detectCharset($string)
+	private static function detectCharset($content)
 	{
-		return mb_detect_encoding($remote_content,
+		return mb_detect_encoding($content,
 				'UTF-8,ISO-8859-1,ISO-8859-2,ISO-8859-3,'.
 				'ISO-8859-4,ISO-8859-5,ISO-8859-6,ISO-8859-7,ISO-8859-8,'.
 				'ISO-8859-9,ISO-8859-10,ISO-8859-13,ISO-8859-14,ISO-8859-15');
