@@ -61,6 +61,24 @@ class wiki2xhtml extends atoum
 
       ->string($wiki2xhtml->transform(sprintf('[%s|%s|%s|%s]', $label, $url, $lang, $title)))
       ->isIdenticalTo(sprintf('<p><a href="%s" hreflang="%s" title="%s">%s</a></p>', $url, $lang, $title, $label))
+
+      ->string($wiki2xhtml->transform(sprintf('[\'\'%s\'\'|%s]', $label, $url)))
+      ->isIdenticalTo(sprintf('<p><a href="%1$s"><em>%2$s</em></a></p>', $url, $label))
+
+      ->string($wiki2xhtml->transform(sprintf('[\'\'%s\'\' (em first)|%s]', $label, $url)))
+      ->isIdenticalTo(sprintf('<p><a href="%1$s"><em>%2$s</em> (em first)</a></p>', $url, $label))
+
+      ->string($wiki2xhtml->transform(sprintf('[(em last) \'\'%s\'\'|%s]', $label, $url)))
+      ->isIdenticalTo(sprintf('<p><a href="%1$s">(em last) <em>%2$s</em></a></p>', $url, $label))
+
+      ->string($wiki2xhtml->transform(sprintf('[(not first) \'\'%s\'\' (not last)|%s]', $label, $url)))
+      ->isIdenticalTo(sprintf('<p><a href="%1$s">(not first) <em>%2$s</em> (not last)</a></p>', $url, $label))
+
+      ->string($wiki2xhtml->transform(sprintf('[__%s__|%s]', $label, $url)))
+      ->isIdenticalTo(sprintf('<p><a href="%1$s"><strong>%2$s</strong></a></p>', $url, $label))
+
+      ->string($wiki2xhtml->transform(sprintf('[em: \'\'%s\'\' and strong: __%s__|%s]', $label, $label, $url)))
+      ->isIdenticalTo(sprintf('<p><a href="%1$s">em: <em>%2$s</em> and strong: <strong>%2$s</strong></a></p>', $url, $label))
       ;
   }
 
@@ -72,6 +90,7 @@ class wiki2xhtml extends atoum
     $title = $faker->text(10);
     $alt = $faker->text(20);
     $url = $faker->url();
+    $legend = $faker->text(30);
 
     $this
       ->string($wiki2xhtml->transform(sprintf('((%s|%s))', $url, $alt)))
@@ -112,7 +131,16 @@ class wiki2xhtml extends atoum
 
       ->string($wiki2xhtml->transform(sprintf('((%s|%s|C|%s))', $url, $alt, $title)))
       ->isIdenticalTo(sprintf('<p><img src="%s" alt="%s" style="display:block; margin:0 auto;" title="%s" /></p>', $url, $alt, $title))
-      ;
+
+      ->string($wiki2xhtml->transform(sprintf('((%s|%s|R|%s|%s))', $url, $alt, $title, $legend)))
+      ->isIdenticalTo(sprintf('<p><figure style="float:right; margin: 0 0 1em 1em;"><img src="%s" alt="%s" title="%s" /><figcaption>%s</figcaption></figure></p>', $url, $alt, $title, $legend))
+
+      ->string($wiki2xhtml->transform(sprintf('((%s|%s|G|%s|%s))', $url, $alt, $title, $legend)))
+      ->isIdenticalTo(sprintf('<p><figure style="float:left; margin: 0 1em 1em 0;"><img src="%s" alt="%s" title="%s" /><figcaption>%s</figcaption></figure></p>', $url, $alt, $title, $legend))
+
+      ->string($wiki2xhtml->transform(sprintf('((%s|%s|C|%s|%s))', $url, $alt, $title, $legend)))
+      ->isIdenticalTo(sprintf('<p><figure style="display:block; margin:0 auto;"><img src="%s" alt="%s" title="%s" /><figcaption>%s</figcaption></figure></p>', $url, $alt, $title, $legend))
+        ;
   }
 
   public function testBlocks($in, $out, $count) {
@@ -130,12 +158,9 @@ class wiki2xhtml extends atoum
     $in = str_replace($search, $replace, $in);
     $out = str_replace($search, $replace, $out);
 
-    /* echo "$in\n"; */
-    /* echo "$out\n"; */
-
     if (strpos($in, '%s')!==false) {
       for ($n=1;$n<=$count;$n++) {
-	$phrase[$n] = $faker->text(20);
+	      $phrase[$n] = $faker->text(20);
       }
 
       $in = vsprintf($in, $phrase);
@@ -198,7 +223,7 @@ class wiki2xhtml extends atoum
     return array(
 		 array('em', array("''","''")),
 		 array('strong', array('__','__')),
-		 array('acronym', array('??','??')),
+		 array('abbr', array('??','??')),
 		 array('q', array('{{','}}')),
 		 array('code', array('@@','@@')),
 		 array('ins', array('++','++')),
@@ -222,7 +247,7 @@ class wiki2xhtml extends atoum
 		 array('{{%s|%lang%|%url%}}', '<p><q lang="%lang%" cite="%url%">%s</q></p>', 1),
 
 		 array(" %s\n %s\n %s", '<pre>%s%s%s</pre>', 3),
-		 array('??%1$s|%2$s??', '<p><acronym title="%2$s">%1$s</acronym></p>', 2),
+		 array('??%1$s|%2$s??', '<p><abbr title="%2$s">%1$s</abbr></p>', 2),
 		 array(">%s\n>%s", '<blockquote><p>%s%s</p></blockquote>', 2),
 
 		 array('----', '<hr />', 0),
@@ -231,7 +256,7 @@ class wiki2xhtml extends atoum
 		 array('!!!%s', '<h3>%s</h3>', 1),
 		 array('!!%s', '<h4>%s</h4>', 1),
 		 array('!%s', '<h5>%s</h5>', 1),
-		 array('~%word%~', '<p><a name="%word%"></a></p>', 1),
+		 array('~%word%~', '<p><a id="%word%"></a></p>', 1),
 
 		 array('@@%s@@', '<p><code>%s</code></p>', 1),
 
@@ -243,6 +268,7 @@ class wiki2xhtml extends atoum
            '%s</p></div>', 2),
      array("* %s\n///\n%s\n///\n","<ul><li>%s</li></ul><pre>%s</pre>", 2),
      array("# %s\n///\n%s\n///\n","<ol><li>%s</li></ol><pre>%s</pre>", 2)
+
 		 );
   }
 
