@@ -3,13 +3,12 @@
 #
 # This file is part of Dotclear 2.
 #
-# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
+# Copyright (c) 2003-2015 Olivier Meunier & Association Dotclear
 # Licensed under the GPL version 2.0 license.
 # See LICENSE file or
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 #
 # -- END LICENSE BLOCK -----------------------------------------
-if (!defined('DC_RC_PATH')) { return; }
 
 class dcTemplate extends template
 {
@@ -74,6 +73,7 @@ class dcTemplate extends template
 		$this->addValue('BlogPublicURL',array($this,'BlogPublicURL'));
 		$this->addValue('BlogQmarkURL',array($this,'BlogQmarkURL'));
 		$this->addValue('BlogMetaRobots',array($this,'BlogMetaRobots'));
+		$this->addValue('BlogJsJQuery',array($this,'BlogJsJQuery'));
 
 		# Categories
 		$this->addBlock('Categories',array($this,'Categories'));
@@ -117,6 +117,7 @@ class dcTemplate extends template
 
 		# Comment preview
 		$this->addBlock('IfCommentPreview',array($this,'IfCommentPreview'));
+		$this->addBlock('IfCommentPreviewOptional',array($this,'IfCommentPreviewOptional'));
 		$this->addValue('CommentPreviewName',array($this,'CommentPreviewName'));
 		$this->addValue('CommentPreviewEmail',array($this,'CommentPreviewEmail'));
 		$this->addValue('CommentPreviewSite',array($this,'CommentPreviewSite'));
@@ -129,7 +130,6 @@ class dcTemplate extends template
 		$this->addBlock('Entries',array($this,'Entries'));
 		$this->addBlock('EntriesFooter',array($this,'EntriesFooter'));
 		$this->addBlock('EntriesHeader',array($this,'EntriesHeader'));
-		$this->addValue('EntryExcerpt',array($this,'EntryExcerpt'));
 		$this->addValue('EntryAuthorCommonName',array($this,'EntryAuthorCommonName'));
 		$this->addValue('EntryAuthorDisplayName',array($this,'EntryAuthorDisplayName'));
 		$this->addValue('EntryAuthorEmail',array($this,'EntryAuthorEmail'));
@@ -145,10 +145,12 @@ class dcTemplate extends template
 		$this->addValue('EntryCommentCount',array($this,'EntryCommentCount'));
 		$this->addValue('EntryContent',array($this,'EntryContent'));
 		$this->addValue('EntryDate',array($this,'EntryDate'));
+		$this->addValue('EntryExcerpt',array($this,'EntryExcerpt'));
 		$this->addValue('EntryFeedID',array($this,'EntryFeedID'));
 		$this->addValue('EntryFirstImage',array($this,'EntryFirstImage'));
 		$this->addValue('EntryID',array($this,'EntryID'));
 		$this->addBlock('EntryIf',array($this,'EntryIf'));
+		$this->addBlock('EntryIfContentCut',array($this,'EntryIfContentCut'));
 		$this->addValue('EntryIfFirst',array($this,'EntryIfFirst'));
 		$this->addValue('EntryIfOdd',array($this,'EntryIfOdd'));
 		$this->addValue('EntryIfSelected',array($this,'EntryIfSelected'));
@@ -234,104 +236,6 @@ class dcTemplate extends template
 		return self::$_r;
 	}
 
-	protected function compileFile($file)
-	{
-		$fc = file_get_contents($file);
-
-		$this->compile_stack[] = $file;
-
-		# Remove every PHP tags
-		if ($this->remove_php)
-		{
-			$fc = preg_replace('/<\?(?=php|=|\s).*?\?>/ms','',$fc);
-		}
-
-		# Transform what could be considered as PHP short tags
-		$fc = preg_replace('/(<\?(?!php|=|\s))(.*?)(\?>)/ms',
-		'<?php echo "$1"; ?>$2<?php echo "$3"; ?>',$fc);
-
-		# Remove template comments <!-- #... -->
-		$fc = preg_replace('/(^\s*)?<!-- #(.*?)-->/ms','',$fc);
-
-		# Lexer part : split file into small pieces
-		# each array entry will be either a tag or plain text
-		$blocks = preg_split(
-			'#(<tpl:\w+[^>]*>)|(</tpl:\w+>)|({{tpl:\w+[^}]*}})#msu',$fc,-1,
-			PREG_SPLIT_DELIM_CAPTURE|PREG_SPLIT_NO_EMPTY);
-
-		# Next : build semantic tree from tokens.
-		$rootNode = new tplNode();
-		$node = $rootNode;
-		$errors = array();
-		foreach ($blocks as $id => $block) {
-			$isblock = preg_match('#<tpl:(\w+)(?:(\s+.*?)>|>)|</tpl:(\w+)>|{{tpl:(\w+)(\s(.*?))?}}#ms',$block,$match);
-			if ($isblock == 1) {
-				if (substr($match[0],1,1) == '/') {
-					// Closing tag, check if it matches current opened node
-					$tag = $match[3];
-					if (($node instanceof tplNodeBlock) && $node->getTag() == $tag) {
-						$node->setClosing();
-						$node = $node->getParent();
-					} else {
-						// Closing tag does not match opening tag
-						// Search if it closes a parent tag
-						$search = $node;
-						while($search->getTag() != 'ROOT' && $search->getTag() != $tag) {
-							$search = $search->getParent();
-						}
-						if ($search->getTag() == $tag) {
-							$errors[] = sprintf(
-								__('Did not find closing tag for block <tpl:%s>. Content has been ignored.'),
-								html::escapeHTML($node->getTag()));
-							$search->setClosing();
-							$node = $search->getParent();
-						} else {
-							$errors[]=sprintf(
-								__('Unexpected closing tag </tpl:%s> found.'),
-								$tag);;
-						}
-					}
-				} elseif (substr($match[0],0,1) == '{') {
-					// Value tag
-					$tag = $match[4];
-					$str_attr = '';
-					$attr = array();
-					if (isset($match[6])) {
-						$str_attr = $match[6];
-						$attr = $this->getAttrs($match[6]);
-					}
-					$node->addChild(new tplNodeValue($tag,$attr,$str_attr));
-				} else {
-					// Opening tag, create new node and dive into it
-					$tag = $match[1];
-					$newnode = new tplNodeBlock($tag,isset($match[2])?$this->getAttrs($match[2]):array());
-					$node->addChild($newnode);
-					$node = $newnode;
-				}
-			} else {
-				// Simple text
-				$node->addChild(new tplNodeText($block));
-			}
-		}
-
-		if (($node instanceof tplNodeBlock) && !$node->isClosed()) {
-			$errors[] = sprintf(
-				__('Did not find closing tag for block <tpl:%s>. Content has been ignored.'),
-				html::escapeHTML($node->getTag()));
-		}
-
-		$err = "";
-		if (count($errors) > 0) {
-			$err = "\n\n<!-- \n".
-				__('WARNING: the following errors have been found while parsing template file :').
-				"\n * ".
-				join("\n * ",$errors).
-				"\n -->\n";
-		}
-
-		return $rootNode->compile($this).$err;
-	}
-
 	public function compileBlockNode($tag,$attr,$content)
 	{
 		$this->current_tag = $tag;
@@ -342,11 +246,7 @@ class dcTemplate extends template
 		# --BEHAVIOR-- templateInsideBlock
 		$this->core->callBehavior('templateInsideBlock',$this->core,$this->current_tag,$attr,array(&$content));
 
-		if (isset($this->blocks[$this->current_tag])) {
-			$res .= call_user_func($this->blocks[$this->current_tag],$attr,$content);
-		} elseif ($this->unknown_block_handler != null) {
-			$res .= call_user_func($this->unknown_block_handler,$this->current_tag,$attr,$content);
-		}
+		$res .= parent::compileBlockNode($this->current_tag,$attr,$content);
 
 		# --BEHAVIOR-- templateAfterBlock
 		$res .= $this->core->callBehavior('templateAfterBlock',$this->core,$this->current_tag,$attr);
@@ -362,11 +262,7 @@ class dcTemplate extends template
 		# --BEHAVIOR-- templateBeforeValue
 		$res = $this->core->callBehavior('templateBeforeValue',$this->core,$this->current_tag,$attr);
 
-		if (isset($this->values[$this->current_tag])) {
-			$res .= call_user_func($this->values[$this->current_tag],$attr,ltrim($str_attr));
-		} elseif ($this->unknown_value_handler != null) {
-			$res .= call_user_func($this->unknown_value_handler,$this->current_tag,$attr,$str_attr);
-		}
+		$res .= parent::compileValueNode($this->current_tag,$attr,$str_attr);
 
 		# --BEHAVIOR-- templateAfterValue
 		$res .= $this->core->callBehavior('templateAfterValue',$this->core,$this->current_tag,$attr);
@@ -374,20 +270,6 @@ class dcTemplate extends template
 		return $res;
 	}
 
-	public function setUnknownValueHandler($callback)
-	{
-		if (is_callable($callback)) {
-			$this->unknown_value_handler = $callback;
-		}
-	}
-
-	public function setUnknownBlockHandler($callback)
-	{
-		if (is_callable($callback)) {
-			$this->unknown_block_handler = $callback;
-		}
-	}
-
 	public function getFilters($attr)
 	{
 		$p[0] = '0';	# encode_xml
@@ -395,6 +277,7 @@ class dcTemplate extends template
 		$p[2] = '0';	# cut_string
 		$p[3] = '0';	# lower_case
 		$p[4] = '0';	# upper_case or capitalize
+		$p[5] = '0';    # encode_url
 
 		$p[0] = (integer) (!empty($attr['encode_xml']) || !empty($attr['encode_html']));
 		$p[1] = (integer) !empty($attr['remove_html']);
@@ -406,6 +289,7 @@ class dcTemplate extends template
 		$p[3] = (integer) !empty($attr['lower_case']);
 		$p[4] = (integer) !empty($attr['upper_case']);
 		$p[4] = (!empty($attr['capitalize']) ? 2 : $p[4]);
+		$p[5] = (integer) !empty($attr['encode_url']);
 
 		return "context::global_filter(%s,".implode(",",$p).",'".addslashes($this->current_tag)."')";
 	}
@@ -459,7 +343,7 @@ class dcTemplate extends template
 				if (!is_array($v)) {
 					$alias[$k] = array();
 				}
-				if (!is_array($v)) {
+				if (!isset($default_alias[$k]) || !is_array($default_alias[$k])) {
 					$default_alias[$k] = array();
 				}
 				$default_alias[$k] = array_merge($default_alias[$k],$alias[$k]);
@@ -504,6 +388,35 @@ class dcTemplate extends template
 		return '';
 	}
 
+	public function displayCounter($variable,$values,$attr,$count_only_by_default=false) {
+		if (isset($attr['count_only'])) {
+			$count_only=($attr['count_only']==1);
+		} else {
+			$count_only = $count_only_by_default;
+		}
+		if ($count_only) {
+			return "<?php echo ".$variable."; ?>";
+		} else {
+			$v=$values;
+			if (isset($attr['none'])) {
+				$v['none'] = addslashes($attr['none']);
+			}
+			if (isset($attr['one'])) {
+				$v['one'] = addslashes($attr['one']);
+			}
+			if (isset($attr['more'])) {
+				$v['more'] = addslashes($attr['more']);
+			}
+			return
+				"<?php if (".$variable." == 0) {\n".
+				"  printf(__('".$v['none']."'),".$variable.");\n".
+				"} elseif (".$variable." == 1) {\n".
+				"  printf(__('".$v['one']."'),".$variable.");\n".
+				"} else {\n".
+				"  printf(__('".$v['more']."'),".$variable.");\n".
+				"} ?>";
+		}
+	}
 	/* TEMPLATE FUNCTIONS
 	------------------------------------------------------- */
 
@@ -520,13 +433,14 @@ class dcTemplate extends template
 		$start = isset($attr['start']) ? (integer) $attr['start'] : '0';
 		$length = isset($attr['length']) ? (integer) $attr['length'] : 'null';
 		$even = isset($attr['even']) ? (integer) (boolean) $attr['even'] : 'null';
+		$modulo = isset($attr['modulo']) ? (integer) $attr['modulo'] : 'null';
 
 		if ($start > 0) {
 			$start--;
 		}
 
 		return
-		'<?php if ($_ctx->loopPosition('.$start.','.$length.','.$even.')) : ?>'.
+		'<?php if ($_ctx->loopPosition('.$start.','.$length.','.$even.','.$modulo.')) : ?>'.
 		$content.
 		"<?php endif; ?>";
 	}
@@ -664,7 +578,16 @@ class dcTemplate extends template
 	public function ArchiveEntriesCount($attr)
 	{
 		$f = $this->getFilters($attr);
-		return '<?php echo '.sprintf($f,'$_ctx->archives->nb_post').'; ?>';
+		return $this->displayCounter(
+			sprintf($f,'$_ctx->archives->nb_post'),
+			array(
+				'none' => 'no archive',
+				'one'  => 'one archive',
+				'more' => '%d archives'
+			),
+			$attr,
+			true
+		);
 	}
 
 	/*dtd
@@ -955,6 +878,15 @@ class dcTemplate extends template
 		return "<?php echo context::robotsPolicy(\$core->blog->settings->system->robots_policy,'".$robots."'); ?>";
 	}
 
+	/*dtd
+	<!ELEMENT gpl:BlogJsJQuery - 0 -- Blog Js jQuery version selected -->
+	*/
+	public function BlogJsJQuery($attr)
+	{
+		$f = $this->getFilters($attr);
+		return '<?php echo '.sprintf($f,'$core->blog->getJsJQuery()').'; ?>';
+	}
+
 	/* Categories ----------------------------------------- */
 
 	/*dtd
@@ -1140,7 +1072,16 @@ class dcTemplate extends template
 	public function CategoryEntriesCount($attr)
 	{
 		$f = $this->getFilters($attr);
-		return '<?php echo '.sprintf($f,'$_ctx->categories->nb_post').'; ?>';
+		return $this->displayCounter(
+			sprintf($f,'$_ctx->categories->nb_post'),
+			array(
+				'none' => 'No post',
+				'one'  => 'One post',
+				'more' => '%d posts'
+			),
+			$attr,
+			true
+		);
 	}
 
 	/* Entries -------------------------------------------- */
@@ -1172,15 +1113,30 @@ class dcTemplate extends template
 		$p = 'if (!isset($_page_number)) { $_page_number = 1; }'."\n";
 
 		if ($lastn != 0) {
+			// Set limit (aka nb of entries needed)
 			if ($lastn > 0) {
+				// nb of entries per page specified in template -> regular pagination
 				$p .= "\$params['limit'] = ".$lastn.";\n";
+				$p .= "\$nb_entry_first_page = \$nb_entry_per_page = ".$lastn.";\n";
 			} else {
-				$p .= "\$params['limit'] = \$_ctx->nb_entry_per_page;\n";
+				// nb of entries per page not specified -> use ctx settings
+				$p .= "\$nb_entry_first_page=\$_ctx->nb_entry_first_page; \$nb_entry_per_page = \$_ctx->nb_entry_per_page;\n";
+				$p .= "if ((\$core->url->type == 'default') || (\$core->url->type == 'default-page')) {\n";
+				$p .= "    \$params['limit'] = (\$_page_number == 1 ? \$nb_entry_first_page : \$nb_entry_per_page);\n";
+				$p .= "} else {\n";
+				$p .= "    \$params['limit'] = \$nb_entry_per_page;\n";
+				$p .= "}\n";
 			}
-
+			// Set offset (aka index of first entry)
 			if (!isset($attr['ignore_pagination']) || $attr['ignore_pagination'] == "0") {
-				$p .= "\$params['limit'] = array(((\$_page_number-1)*\$params['limit']),\$params['limit']);\n";
+				// standard pagination, set offset
+				$p .= "if ((\$core->url->type == 'default') || (\$core->url->type == 'default-page')) {\n";
+				$p .= "    \$params['limit'] = array((\$_page_number == 1 ? 0 : (\$_page_number - 2) * \$nb_entry_per_page + \$nb_entry_first_page),\$params['limit']);\n";
+				$p .= "} else {\n";
+				$p .= "    \$params['limit'] = array((\$_page_number - 1) * \$nb_entry_per_page,\$params['limit']);\n";
+				$p .= "}\n";
 			} else {
+				// no pagination, get all posts from 0 to limit
 				$p .= "\$params['limit'] = array(0, \$params['limit']);\n";
 			}
 		}
@@ -1477,7 +1433,7 @@ class dcTemplate extends template
 	}
 
 	/*dtd
-	<!ELEMENT tpl:EntryContent - O -- Entry content -->
+	<!ELEMENT tpl:EntryContent -  -- Entry content -->
 	<!ATTLIST tpl:EntryContent
 	absolute_urls	CDATA	#IMPLIED -- transforms local URLs to absolute one
 	full			(1|0)	#IMPLIED -- returns full content with excerpt
@@ -1500,6 +1456,36 @@ class dcTemplate extends template
 		}
 	}
 
+	/*dtd
+	<!ELEMENT tpl:EntryIfContentCut - - -- Test if Entry content has been cut -->
+	<!ATTLIST tpl:EntryIfContentCut
+	absolute_urls	CDATA	#IMPLIED -- transforms local URLs to absolute one
+	full			(1|0)	#IMPLIED -- test with full content and excerpt
+	>
+	*/
+	public function EntryIfContentCut($attr,$content)
+	{
+		if (empty($attr['cut_string']) || !empty($attr['full'])) {
+			return '';
+		}
+
+		$urls = '0';
+		if (!empty($attr['absolute_urls'])) {
+			$urls = '1';
+		}
+
+		$short = $this->getFilters($attr);
+		$cut = $attr['cut_string'];
+		$attr['cut_string'] = 0;
+		$full = $this->getFilters($attr);
+		$attr['cut_string'] = $cut;
+
+		return '<?php if (strlen('.sprintf($full,'$_ctx->posts->getContent('.$urls.')').') > '.
+			'strlen('.sprintf($short,'$_ctx->posts->getContent('.$urls.')').')) : ?>'.
+			$content.
+			'<?php endif; ?>';
+	}
+
 	/*dtd
 	<!ELEMENT tpl:EntryExcerpt - O -- Entry excerpt -->
 	<!ATTLIST tpl:EntryExcerpt
@@ -1834,10 +1820,13 @@ class dcTemplate extends template
 		"<?php endif; ?>";
 	}
 
+
+
+
 	/*dtd
 	<!ELEMENT tpl:EntryCommentCount - O -- Number of comments for entry -->
 	<!ATTLIST tpl:EntryCommentCount
-	none		CDATA	#IMPLIED	-- text to display for "no comment" (default: no comment)
+	none		CDATA	#IMPLIED	-- text to display for "no comments" (default: no comments)
 	one		CDATA	#IMPLIED	-- text to display for "one comment" (default: one comment)
 	more		CDATA	#IMPLIED	-- text to display for "more comments" (default: %s comments, %s is replaced by the number of comment)
 	count_all	CDATA	#IMPLIED	-- count comments and trackbacks
@@ -1845,68 +1834,44 @@ class dcTemplate extends template
 	*/
 	public function EntryCommentCount($attr)
 	{
-		$none = 'no comment';
-		$one = 'one comment';
-		$more = '%d comments';
-
-		if (isset($attr['none'])) {
-			$none = addslashes($attr['none']);
-		}
-		if (isset($attr['one'])) {
-			$one = addslashes($attr['one']);
-		}
-		if (isset($attr['more'])) {
-			$more = addslashes($attr['more']);
-		}
-
 		if (empty($attr['count_all'])) {
 			$operation = '$_ctx->posts->nb_comment';
 		} else {
 			$operation = '($_ctx->posts->nb_comment + $_ctx->posts->nb_trackback)';
 		}
 
-		return
-		"<?php if (".$operation." == 0) {\n".
-		"  printf(__('".$none."'),".$operation.");\n".
-		"} elseif (".$operation." == 1) {\n".
-		"  printf(__('".$one."'),".$operation.");\n".
-		"} else {\n".
-		"  printf(__('".$more."'),".$operation.");\n".
-		"} ?>";
+		return $this->displayCounter(
+			$operation,
+			array(
+				'none' => 'no comments',
+				'one'  => 'one comment',
+				'more' => '%d comments'
+				),
+			$attr,
+			false
+		);
 	}
 
 	/*dtd
 	<!ELEMENT tpl:EntryPingCount - O -- Number of trackbacks for entry -->
 	<!ATTLIST tpl:EntryPingCount
-	none	CDATA	#IMPLIED	-- text to display for "no ping" (default: no ping)
+	none	CDATA	#IMPLIED	-- text to display for "no pings" (default: no pings)
 	one	CDATA	#IMPLIED	-- text to display for "one ping" (default: one ping)
 	more	CDATA	#IMPLIED	-- text to display for "more pings" (default: %s trackbacks, %s is replaced by the number of pings)
 	>
 	*/
 	public function EntryPingCount($attr)
 	{
-		$none = 'no trackback';
-		$one = 'one trackback';
-		$more = '%d trackbacks';
-
-		if (isset($attr['none'])) {
-			$none = addslashes($attr['none']);
-		}
-		if (isset($attr['one'])) {
-			$one = addslashes($attr['one']);
-		}
-		if (isset($attr['more'])) {
-			$more = addslashes($attr['more']);
-		}
-
-		return
-		"<?php if (\$_ctx->posts->nb_trackback == 0) {\n".
-		"  printf(__('".$none."'),(integer) \$_ctx->posts->nb_trackback);\n".
-		"} elseif (\$_ctx->posts->nb_trackback == 1) {\n".
-		"  printf(__('".$one."'),(integer) \$_ctx->posts->nb_trackback);\n".
-		"} else {\n".
-		"  printf(__('".$more."'),(integer) \$_ctx->posts->nb_trackback);\n".
-		"} ?>";
+		return $this->displayCounter(
+			'$_ctx->posts->nb_trackback',
+			array(
+				'none' => 'no trackbacks',
+				'one'  => 'one trackback',
+				'more' => '%d trackbacks'
+				),
+			$attr,
+			false
+		);
 	}
 
 	/*dtd
@@ -2493,6 +2458,17 @@ class dcTemplate extends template
 	}
 
 	/* Comment preview -------------------------------- */
+	/*dtd
+	<!ELEMENT tpl:IfCommentPreviewOptional - - -- Container displayed if comment preview is optional or currently previewed -->
+	*/
+	public function IfCommentPreviewOptional($attr,$content)
+	{
+		return
+		'<?php if ($core->blog->settings->system->comment_preview_optional || ($_ctx->comment_preview !== null && $_ctx->comment_preview["preview"])) : ?>'.
+		$content.
+		'<?php endif; ?>';
+	}
+
 	/*dtd
 	<!ELEMENT tpl:IfCommentPreview - - -- Container displayed if comment is being previewed -->
 	*/
@@ -3042,128 +3018,3 @@ class dcTemplate extends template
 		return '<?php else: ?>';
 	}
 }
-
-# Template nodes, for parsing purposes
-
-# Generic list node, this one may only be instanciated
-# once for root element
-class tplNode
-{
-	# Basic tree structure : links to parent, children forrest
-	protected $parentNode;
-	protected $children;
-
-	public function __construct() {
-		$this->children = array();
-		$this->parentNode = null;
-	}
-
-	// Returns compiled block
-	public function compile($tpl) {
-		$res='';
-		foreach ($this->children as $child) {
-			$res .= $child->compile($tpl);
-		}
-		return $res;
-	}
-
-	# Add a children to current node
-	public function addChild ($child) {
-		$this->children[] = $child;
-		$child->setParent($this);
-	}
-
-	# Defines parent for current node
-	protected function setParent($parent) {
-		$this->parentNode = $parent;
-	}
-
-	# Retrieves current node parent.
-	# If parent is root node, null is returned
-	public function getParent() {
-		return $this->parentNode;
-	}
-
-	# Current node tag
-	public function getTag() {
-		return "ROOT";
-	}
-}
-
-// Text node, for any non-tpl content
-class tplNodeText extends tplNode
-{
-	// Simple text node, only holds its content
-	protected $content;
-
-	public function __construct($text) {
-		parent::__construct();
-		$this->content=$text;
-	}
-
-	public function compile($tpl) {
-		return $this->content;
-	}
-
-	public function getTag() {
-		return "TEXT";
-	}
-}
-
-// Block node, for all <tpl:Tag>...</tpl:Tag>
-class tplNodeBlock extends tplNode
-{
-	protected $attr;
-	protected $tag;
-	protected $closed;
-
-	public function __construct($tag,$attr) {
-		parent::__construct();
-		$this->content='';
-		$this->tag = $tag;
-		$this->attr = $attr;
-		$this->closed=false;
-	}
-	public function setClosing() {
-		$this->closed = true;
-	}
-	public function isClosed() {
-		return $this->closed;
-	}
-	public function compile($tpl) {
-		if ($this->closed) {
-			$content = parent::compile($tpl);
-			return $tpl->compileBlockNode($this->tag,$this->attr,$content);
-		} else {
-			// if tag has not been closed, silently ignore its content...
-			return '';
-		}
-	}
-	public function getTag() {
-		return $this->tag;
-	}
-}
-
-// Value node, for all {{tpl:Tag}}
-class tplNodeValue extends tplNode
-{
-	protected $attr;
-	protected $str_attr;
-	protected $tag;
-
-	public function __construct($tag,$attr,$str_attr) {
-		parent::__construct();
-		$this->content='';
-		$this->tag = $tag;
-		$this->attr = $attr;
-		$this->str_attr = $str_attr;
-	}
-
-	public function compile($tpl) {
-		return $tpl->compileValueNode($this->tag,$this->attr,$this->str_attr);
-	}
-
-	public function getTag() {
-		return $this->tag;
-	}
-}
