@@ -58,7 +58,7 @@ class context
 	}
 
 	# Loop position tests
-	public function loopPosition($start,$length=null,$even=null)
+	public function loopPosition($start,$length=null,$even=null,$modulo=null)
 	{
 		if (!$this->cur_loop) {
 			return false;
@@ -95,13 +95,16 @@ class context
 			$test = $test && $index%2 == $even;
 		}
 
+		if ($modulo !== null) {
+			$test = $test && ($index % $modulo == 0);
+		}
+
 		return $test;
 	}
 
-
-	# Static methods
+    # Static methods
 	public static function global_filter($str,
-	$encode_xml, $remove_html, $cut_string, $lower_case, $upper_case ,$tag='')
+		$encode_xml, $remove_html, $cut_string, $lower_case, $upper_case ,$encode_url ,$tag='')
 	{
 		$args = func_get_args();
 		array_pop($args);
@@ -132,6 +135,9 @@ class context
 				$str = self::upper_case($str);
 			}
 		}
+		if ($encode_url) {
+			$str = self::encode_url($str);
+		}
 
 		# --BEHAVIOR-- publicAfterContentFilter
 		$res = $GLOBALS['core']->callBehavior('publicAfterContentFilter',$GLOBALS['core'],$tag,$args);
@@ -139,6 +145,10 @@ class context
 		return $str;
 	}
 
+	public static function encode_url($str)
+	{
+		return urlencode($str);
+	}
 
 	public static function cut_string($str,$l)
 	{
@@ -205,9 +215,11 @@ class context
 		}
 
 		$nb_posts = $_ctx->pagination->f(0);
-		$nb_per_page = $_ctx->post_params['limit'][1];
-
-		$nb_pages = ceil($nb_posts/$nb_per_page);
+		if (($GLOBALS['core']->url->type == 'default') || ($GLOBALS['core']->url->type == 'default-page')) {
+			$nb_pages = ceil(($nb_posts - $_ctx->nb_entry_first_page) / $_ctx->nb_entry_per_page + 1);
+		} else {
+			$nb_pages = ceil($nb_posts / $_ctx->nb_entry_per_page);
+		}
 
 		return $nb_pages;
 	}
@@ -305,6 +317,9 @@ class context
 		$path = array();
 		if (isset($GLOBALS['__theme'])) {
 			$path[] = $GLOBALS['__theme'];
+			if (isset($GLOBALS['__parent_theme'])) {
+				$path[] = $GLOBALS['__parent_theme'];
+			}
 		}
 		$path[] = 'default';
 		$definition = $blog->themes_path.'/%s/smilies/smilies.txt';
@@ -501,6 +516,10 @@ class context
 			{
 				$res = '.'.$base.'_'.$size.'.jpg';
 			}
+			elseif ($size != 'o' && file_exists($root.'/'.$info['dirname'].'/.'.$base.'_'.$size.'.png'))
+			{
+				$res = '.'.$base.'_'.$size.'.png';
+			}
 			else
 			{
 				$f = $root.'/'.$info['dirname'].'/'.$base;
