@@ -57,7 +57,6 @@ $GLOBALS['__l10n']['Blogs'] = '';
 $GLOBALS['__l10n']['Blog ID:'] = '';
 $GLOBALS['__l10n']['Required field'] = '';
 $GLOBALS['__l10n']['At least 2 characters using letters, numbers or symbols.'] = '';
-$GLOBALS['__l10n']['Please note that changing your blog ID may require changes in your public index.php file.'] = '';
 $GLOBALS['__l10n']['Blog name:'] = '';
 $GLOBALS['__l10n']['Blog URL:'] = '';
 $GLOBALS['__l10n']['Blog description:'] = '';
@@ -95,6 +94,7 @@ $GLOBALS['__l10n']['Center'] = '';
 $GLOBALS['__l10n']['I would like search engines and archivers to index and archive my blog\'s content.'] = '';
 $GLOBALS['__l10n']['I would like search engines and archivers to index but not archive my blog\'s content.'] = '';
 $GLOBALS['__l10n']['I would like to prevent search engines and archivers from indexing or archiving my blog\'s content.'] = '';
+$GLOBALS['__l10n']['Default'] = '';
 $GLOBALS['__l10n']['This blog ID is already used.'] = '';
 $GLOBALS['__l10n']['Invalid language code'] = '';
 $GLOBALS['__l10n']['Blog has been successfully updated.'] = '';
@@ -104,6 +104,7 @@ $GLOBALS['__l10n']['Warning: except for special configurations, it is generally
 $GLOBALS['__l10n']['Blog has been successfully created.'] = '';
 $GLOBALS['__l10n']['Parameters'] = '';
 $GLOBALS['__l10n']['Blog details'] = '';
+$GLOBALS['__l10n']['Please note that changing your blog ID may require changes in your public index.php file.'] = '';
 $GLOBALS['__l10n']['URL scan method:'] = '';
 $GLOBALS['__l10n']['The URL of blog or the URL scan method might not be well set (<code>%s</code> return a <strong>%s</strong> status).'] = '';
 $GLOBALS['__l10n']['The URL of blog or the URL scan method might not be well set (<code>%s</code> does not return an ATOM feed).'] = '';
@@ -128,6 +129,7 @@ $GLOBALS['__l10n']['Moderate comments'] = '';
 $GLOBALS['__l10n']['Leave comments open for %s days'] = '';
 $GLOBALS['__l10n']['No limit: leave blank.'] = '';
 $GLOBALS['__l10n']['Wiki syntax for comments'] = '';
+$GLOBALS['__l10n']['Preview of comment before submit is not mandatory'] = '';
 $GLOBALS['__l10n']['Accept trackbacks'] = '';
 $GLOBALS['__l10n']['Moderate trackbacks'] = '';
 $GLOBALS['__l10n']['Leave trackbacks open for %s days'] = '';
@@ -139,6 +141,7 @@ $GLOBALS['__l10n']['Sample:'] = '';
 $GLOBALS['__l10n']['Time format:'] = '';
 $GLOBALS['__l10n']['Pattern of time'] = '';
 $GLOBALS['__l10n']['Display smilies on entries and comments'] = '';
+$GLOBALS['__l10n']['Display %s entries on home page'] = '';
 $GLOBALS['__l10n']['Display %s entries per page'] = '';
 $GLOBALS['__l10n']['Display %s entries per feed'] = '';
 $GLOBALS['__l10n']['Display %s comments per feed'] = '';
@@ -151,11 +154,16 @@ $GLOBALS['__l10n']['Generated image sizes (in pixels)'] = '';
 $GLOBALS['__l10n']['Default image insertion attributes'] = '';
 $GLOBALS['__l10n']['Inserted image title'] = '';
 $GLOBALS['__l10n']['Use original media date if possible'] = '';
+$GLOBALS['__l10n']['Do not display date if alone in title'] = '';
 $GLOBALS['__l10n']['It is retrieved from the picture\'s metadata.'] = '';
 $GLOBALS['__l10n']['Size of inserted image:'] = '';
 $GLOBALS['__l10n']['Image alignment:'] = '';
 $GLOBALS['__l10n']['Insert a link to the original image'] = '';
 $GLOBALS['__l10n']['Search engines robots policy'] = '';
+$GLOBALS['__l10n']['jQuery javascript library'] = '';
+$GLOBALS['__l10n']['jQuery version to be loaded for this blog:'] = '';
+$GLOBALS['__l10n']['Blog security'] = '';
+$GLOBALS['__l10n']['Protect the blog from Clickjacking (see <a href="https://en.wikipedia.org/wiki/Clickjacking">Wikipedia</a>)'] = '';
 $GLOBALS['__l10n']['Save'] = '';
 $GLOBALS['__l10n']['The current blog cannot be deleted.'] = '';
 $GLOBALS['__l10n']['Only superadmin can delete a blog.'] = '';
@@ -258,7 +266,7 @@ $GLOBALS['__l10n']['before'] = '';
 $GLOBALS['__l10n']['position: '] = '';
 $GLOBALS['__l10n']['Entry does not exist.'] = '';
 $GLOBALS['__l10n']['Comment has been successfully created.'] = '';
-$GLOBALS['__l10n']['No comment'] = '';
+$GLOBALS['__l10n']['No comments'] = '';
 $GLOBALS['__l10n']['Comment has been successfully updated.'] = '';
 $GLOBALS['__l10n']['Comment has been successfully deleted.'] = '';
 $GLOBALS['__l10n']['You can\'t edit this comment.'] = '';
@@ -320,6 +328,7 @@ $GLOBALS['__l10n']['The cache directory does not exist or is not writable. You m
 $GLOBALS['__l10n']['The cache directory does not exist or is not writable. You should contact your administrator.'] = '';
 $GLOBALS['__l10n']['There is no writable directory /public/ at the location set in about:config "public_path". You must create this directory with sufficient rights (or change this setting).'] = '';
 $GLOBALS['__l10n']['There is no writable root directory for the media manager. You should contact your administrator.'] = '';
+$GLOBALS['__l10n']['Error:'] = '';
 $GLOBALS['__l10n']['Following plugins have been installed:'] = '';
 $GLOBALS['__l10n']['Following plugins have not been installed:'] = '';
 $GLOBALS['__l10n']['Errors have occured with following plugins:'] = '';
@@ -440,6 +449,7 @@ $GLOBALS['__l10n']['Directory "%s" has been successfully created.'] = '';
 $GLOBALS['__l10n']['Files have been successfully uploaded.'] = '';
 $GLOBALS['__l10n']['Successfully delete one media.'][0] = '';
 $GLOBALS['__l10n']['Successfully delete one media.'][1] = '';
+$GLOBALS['__l10n']['Directory has been successfully removed.'] = '';
 $GLOBALS['__l10n']['File has been successfully removed.'] = '';
 $GLOBALS['__l10n']['Directory "%s" has been successfully rebuilt.'] = '';
 $GLOBALS['__l10n']['Media manager'] = '';
@@ -449,7 +459,6 @@ $GLOBALS['__l10n']['Cancel'] = '';
 $GLOBALS['__l10n']['Yes'] = '';
 $GLOBALS['__l10n']['You do not have sufficient permissions to write to this folder.'] = '';
 $GLOBALS['__l10n']['Directory has been successfully created.'] = '';
-$GLOBALS['__l10n']['Directory has been successfully removed.'] = '';
 $GLOBALS['__l10n']['Directory has been successfully rebuilt.'] = '';
 $GLOBALS['__l10n']['Zip file has been successfully extracted.'] = '';
 $GLOBALS['__l10n']['Choose a file to attach to entry %s by clicking on %s.'] = '';
@@ -642,7 +651,6 @@ $GLOBALS['__l10n']['Month:'] = '';
 $GLOBALS['__l10n']['Lang:'] = '';
 $GLOBALS['__l10n']['entries per page'] = '';
 $GLOBALS['__l10n']['Selected entries action:'] = '';
-$GLOBALS['__l10n']['Default'] = '';
 $GLOBALS['__l10n']['If you want to change your email or password you must provide your current password.'] = '';
 $GLOBALS['__l10n']['Personal information has been successfully updated.'] = '';
 $GLOBALS['__l10n']['Personal options has been successfully updated.'] = '';
@@ -670,6 +678,8 @@ $GLOBALS['__l10n']['Number of elements displayed per page in media manager:'] =
 $GLOBALS['__l10n']['Do not use standard favicon'] = '';
 $GLOBALS['__l10n']['This will be applied for all users'] = '';
 $GLOBALS['__l10n']['Edition'] = '';
+$GLOBALS['__l10n']['Preferred editor for %s:'] = '';
+$GLOBALS['__l10n']['Choose an editor'] = '';
 $GLOBALS['__l10n']['Preferred format:'] = '';
 $GLOBALS['__l10n']['Default entry status:'] = '';
 $GLOBALS['__l10n']['Entry edit field height:'] = '';
@@ -818,7 +828,6 @@ $GLOBALS['__l10n']['Hide main menu'] = '';
 $GLOBALS['__l10n']['Show main menu'] = '';
 $GLOBALS['__l10n']['Safe mode'] = '';
 $GLOBALS['__l10n']['You are in safe mode. All plugins have been temporarily disabled. Remind to log out then log in again normally to get back all functionalities'] = '';
-$GLOBALS['__l10n']['Error:'] = '';
 $GLOBALS['__l10n']['[%H:%M:%S]'] = '';
 $GLOBALS['__l10n']['Thank you for using %s.'] = '';
 $GLOBALS['__l10n']['Go to dashboard'] = '';
@@ -848,6 +857,7 @@ $GLOBALS['__l10n']['Are you sure you want to delete selected users (%s)?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete category "%s"?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to reorder all categories?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to remove media "%s"?'] = '';
+$GLOBALS['__l10n']['Are you sure you want to remove directory "%s"?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to extract archive in current directory?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to remove attachment "%s"?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete "%s" language?'] = '';
@@ -858,6 +868,7 @@ $GLOBALS['__l10n']['Remove this theme'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete "%s" theme?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete selected themes?'] = '';
 $GLOBALS['__l10n']['Are you sure you want to delete this backup?'] = '';
+$GLOBALS['__l10n']['Are you sure you want to revert to this backup?'] = '';
 $GLOBALS['__l10n']['Zip file content'] = '';
 $GLOBALS['__l10n']['XHTML markup validator'] = '';
 $GLOBALS['__l10n']['XHTML content is valid.'] = '';
@@ -872,37 +883,9 @@ $GLOBALS['__l10n']['Help:'] = '';
 $GLOBALS['__l10n']['Section:'] = '';
 $GLOBALS['__l10n']['Tags:'] = '';
 $GLOBALS['__l10n']['You have unsaved changes.'] = '';
+$GLOBALS['__l10n']['Choose date'] = '';
 $GLOBALS['__l10n']['close'] = '';
 $GLOBALS['__l10n']['now'] = '';
-$GLOBALS['__l10n']['visual'] = '';
-$GLOBALS['__l10n']['source'] = '';
-$GLOBALS['__l10n']['You can use the following shortcuts to format your text.'] = '';
-$GLOBALS['__l10n']['-- none --'] = '';
-$GLOBALS['__l10n']['-- block format --'] = '';
-$GLOBALS['__l10n']['Paragraph'] = '';
-$GLOBALS['__l10n']['Level 1 header'] = '';
-$GLOBALS['__l10n']['Level 2 header'] = '';
-$GLOBALS['__l10n']['Level 3 header'] = '';
-$GLOBALS['__l10n']['Level 4 header'] = '';
-$GLOBALS['__l10n']['Level 5 header'] = '';
-$GLOBALS['__l10n']['Level 6 header'] = '';
-$GLOBALS['__l10n']['Strong emphasis'] = '';
-$GLOBALS['__l10n']['Emphasis'] = '';
-$GLOBALS['__l10n']['Inserted'] = '';
-$GLOBALS['__l10n']['Deleted'] = '';
-$GLOBALS['__l10n']['Inline quote'] = '';
-$GLOBALS['__l10n']['Code'] = '';
-$GLOBALS['__l10n']['Line break'] = '';
-$GLOBALS['__l10n']['Blockquote'] = '';
-$GLOBALS['__l10n']['Preformated text'] = '';
-$GLOBALS['__l10n']['Unordered list'] = '';
-$GLOBALS['__l10n']['Ordered list'] = '';
-$GLOBALS['__l10n']['Link'] = '';
-$GLOBALS['__l10n']['URL?'] = '';
-$GLOBALS['__l10n']['Language?'] = '';
-$GLOBALS['__l10n']['External image'] = '';
-$GLOBALS['__l10n']['Media chooser'] = '';
-$GLOBALS['__l10n']['Link to an entry'] = '';
 $GLOBALS['__l10n']['Temporarily activate enhanced uploader'] = '';
 $GLOBALS['__l10n']['Temporarily disable enhanced uploader'] = '';
 $GLOBALS['__l10n']['Limit exceeded.'] = '';
@@ -938,30 +921,26 @@ $GLOBALS['__l10n']['Activate'] = '';
 $GLOBALS['__l10n']['Deactivate'] = '';
 $GLOBALS['__l10n']['Install'] = '';
 $GLOBALS['__l10n']['Update'] = '';
-$GLOBALS['__l10n']['No such plugin.'] = '';
-$GLOBALS['__l10n']['Plugin has been successfully activated.'][0] = '';
-$GLOBALS['__l10n']['Plugin has been successfully activated.'][1] = '';
-$GLOBALS['__l10n']['You don\'t have permissions to deactivate this plugin.'] = '';
-$GLOBALS['__l10n']['Plugin has been successfully deactivated.'][0] = '';
-$GLOBALS['__l10n']['Plugin has been successfully deactivated.'][1] = '';
-$GLOBALS['__l10n']['You don\'t have permissions to delete this plugin.'] = '';
-$GLOBALS['__l10n']['Some plugins have not been deleted.'] = '';
-$GLOBALS['__l10n']['Plugin has been successfully deleted.'][0] = '';
-$GLOBALS['__l10n']['Plugin has been successfully deleted.'][1] = '';
-$GLOBALS['__l10n']['Plugin has been successfully updated.'][0] = '';
-$GLOBALS['__l10n']['Plugin has been successfully updated.'][1] = '';
-$GLOBALS['__l10n']['Plugin has been successfully installed.'][0] = '';
-$GLOBALS['__l10n']['Plugin has been successfully installed.'][1] = '';
 $GLOBALS['__l10n']['Activate selected plugins'] = '';
 $GLOBALS['__l10n']['Activate all plugins from this list'] = '';
-$GLOBALS['__l10n']['Plugins have been successfully activated.'] = '';
 $GLOBALS['__l10n']['Deactivate selected plugins'] = '';
 $GLOBALS['__l10n']['Deactivate all plugins from this list'] = '';
-$GLOBALS['__l10n']['Plugins have been successfully deactivated.'] = '';
-$GLOBALS['__l10n']['Some plugins have not been deactivated.'] = '';
 $GLOBALS['__l10n']['Update selected plugins'] = '';
 $GLOBALS['__l10n']['Update all plugins from this list'] = '';
-$GLOBALS['__l10n']['Plugins have been successfully updated.'] = '';
+$GLOBALS['__l10n']['No such plugin.'] = '';
+$GLOBALS['__l10n']['You don\'t have permissions to delete this plugin.'] = '';
+$GLOBALS['__l10n']['Some plugins have not been delete.'] = '';
+$GLOBALS['__l10n']['Plugin has been successfully deleted.'][0] = '';
+$GLOBALS['__l10n']['Plugin has been successfully deleted.'][1] = '';
+$GLOBALS['__l10n']['Plugin has been successfully installed.'][0] = '';
+$GLOBALS['__l10n']['Plugin has been successfully installed.'][1] = '';
+$GLOBALS['__l10n']['Plugin has been successfully activated.'][0] = '';
+$GLOBALS['__l10n']['Plugin has been successfully activated.'][1] = '';
+$GLOBALS['__l10n']['Some plugins have not been deactivated.'] = '';
+$GLOBALS['__l10n']['Plugin has been successfully deactivated.'][0] = '';
+$GLOBALS['__l10n']['Plugin has been successfully deactivated.'][1] = '';
+$GLOBALS['__l10n']['Plugin has been successfully updated.'][0] = '';
+$GLOBALS['__l10n']['Plugin has been successfully updated.'][1] = '';
 $GLOBALS['__l10n']['Zip file path:'] = '';
 $GLOBALS['__l10n']['Download a zip file'] = '';
 $GLOBALS['__l10n']['Zip file URL:'] = '';
@@ -987,7 +966,6 @@ $GLOBALS['__l10n']['No such theme.'] = '';
 $GLOBALS['__l10n']['Theme has been successfully selected.'] = '';
 $GLOBALS['__l10n']['Theme has been successfully activated.'][0] = '';
 $GLOBALS['__l10n']['Theme has been successfully activated.'][1] = '';
-$GLOBALS['__l10n']['You don\'t have permissions to deactivate this theme.'] = '';
 $GLOBALS['__l10n']['Some themes have not been deactivated.'] = '';
 $GLOBALS['__l10n']['Theme has been successfully deactivated.'][0] = '';
 $GLOBALS['__l10n']['Theme has been successfully deactivated.'][1] = '';
@@ -995,11 +973,10 @@ $GLOBALS['__l10n']['You don\'t have permissions to delete this theme.'] = '';
 $GLOBALS['__l10n']['Some themes have not been delete.'] = '';
 $GLOBALS['__l10n']['Theme has been successfully deleted.'][0] = '';
 $GLOBALS['__l10n']['Theme has been successfully deleted.'][1] = '';
-$GLOBALS['__l10n']['Theme has been successfully updated.'][0] = '';
-$GLOBALS['__l10n']['Theme has been successfully updated.'][1] = '';
-$GLOBALS['__l10n']['Update all theme from this list'] = '';
 $GLOBALS['__l10n']['Theme has been successfully installed.'][0] = '';
 $GLOBALS['__l10n']['Theme has been successfully installed.'][1] = '';
+$GLOBALS['__l10n']['Theme has been successfully updated.'][0] = '';
+$GLOBALS['__l10n']['Theme has been successfully updated.'][1] = '';
 $GLOBALS['__l10n']['First page'] = '';
 $GLOBALS['__l10n']['Previous page'] = '';
 $GLOBALS['__l10n']['Next page'] = '';
@@ -1030,6 +1007,15 @@ $GLOBALS['__l10n']['List of %s users match the filter.'] = '';
 $GLOBALS['__l10n']['Users list'] = '';
 $GLOBALS['__l10n']['admin'] = '';
 $GLOBALS['__l10n']['superadmin'] = '';
+$GLOBALS['__l10n']['ratio %.1f'] = '';
+$GLOBALS['__l10n']['(%s)'] = '';
+$GLOBALS['__l10n']['The \'public\' directory does not exist.'] = '';
+$GLOBALS['__l10n']['The \'%s\' directory cannot be modified.'] = '';
+$GLOBALS['__l10n']['At least one of the following functions is not available: imagecreatetruecolor, imagepng & imagecreatefrompng.'] = '';
+$GLOBALS['__l10n']['Unable to create images.'] = '';
+$GLOBALS['__l10n']['Invalid file type.'] = '';
+$GLOBALS['__l10n']['An error occurred while writing the file.'] = '';
+$GLOBALS['__l10n']['Uploaded image is not %s pixels wide.'] = '';
 $GLOBALS['__l10n']['Database error'] = '';
 $GLOBALS['__l10n']['There seems to be no Session table in your database. Is Dotclear completly installed?'] = '';
 $GLOBALS['__l10n']['System settings'] = '';
@@ -1107,6 +1093,7 @@ $GLOBALS['__l10n']['The zip file does not appear to be a valid Dotclear module.'
 $GLOBALS['__l10n']['An error occurred during module deletion.'] = '';
 $GLOBALS['__l10n']['Unable to upgrade "%s". (older or same version)'] = '';
 $GLOBALS['__l10n']['Unable to read new _define.php file'] = '';
+$GLOBALS['__l10n']['No such module.'] = '';
 $GLOBALS['__l10n']['Cannot remove module files'] = '';
 $GLOBALS['__l10n']['Cannot deactivate plugin.'] = '';
 $GLOBALS['__l10n']['Cannot activate plugin.'] = '';
@@ -1162,6 +1149,7 @@ $GLOBALS['__l10n']['The uploaded file was only partially uploaded.'] = '';
 $GLOBALS['__l10n']['No file was uploaded.'] = '';
 $GLOBALS['__l10n']['Missing a temporary folder.'] = '';
 $GLOBALS['__l10n']['Failed to write file to disk.'] = '';
+$GLOBALS['__l10n']['A PHP extension stopped the file upload.'] = '';
 $GLOBALS['__l10n']['%s is not a directory.'] = '';
 $GLOBALS['__l10n']['Bad range'] = '';
 $GLOBALS['__l10n']['Invalid range'] = '';
@@ -1174,7 +1162,6 @@ $GLOBALS['__l10n']['Uploading this file is not allowed.'] = '';
 $GLOBALS['__l10n']['Destination directory is not in jail.'] = '';
 $GLOBALS['__l10n']['File already exists.'] = '';
 $GLOBALS['__l10n']['Cannot write in this directory.'] = '';
-$GLOBALS['__l10n']['An error occurred while writing the file.'] = '';
 $GLOBALS['__l10n']['Source file does not exist.'] = '';
 $GLOBALS['__l10n']['File is not in jail.'] = '';
 $GLOBALS['__l10n']['Destination directory is not writable.'] = '';
@@ -1183,6 +1170,9 @@ $GLOBALS['__l10n']['File cannot be removed.'] = '';
 $GLOBALS['__l10n']['Directory is not in jail.'] = '';
 $GLOBALS['__l10n']['Directory cannot be removed.'] = '';
 $GLOBALS['__l10n']['Not enough memory to open image.'] = '';
+$GLOBALS['__l10n']['Did not find closing tag for block <tpl:%s>. Content has been ignored.'] = '';
+$GLOBALS['__l10n']['Unexpected closing tag </tpl:%s> found.'] = '';
+$GLOBALS['__l10n']['WARNING: the following errors have been found while parsing template file :'] = '';
 $GLOBALS['__l10n']['singular'][0] = '';
 $GLOBALS['__l10n']['singular'][1] = '';
 $GLOBALS['__l10n']['File %s is not compressed in the zip.'] = '';
