@@ -24,13 +24,13 @@ $GLOBALS['__l10n']['by'] = 'par';
 $GLOBALS['__l10n']['on'] = 'le';
 $GLOBALS['__l10n']['On'] = 'Le';
 $GLOBALS['__l10n']['Continue reading'] = 'Lire la suite';
-$GLOBALS['__l10n']['no comment'] = 'aucun commentaire';
+$GLOBALS['__l10n']['no comments'] = 'aucun commentaire';
 $GLOBALS['__l10n']['one comment'] = 'un commentaire';
 $GLOBALS['__l10n']['%d comments'] = '%d commentaires';
-$GLOBALS['__l10n']['no trackback'] = 'aucun rétrolien';
+$GLOBALS['__l10n']['no trackbacks'] = 'aucun rétrolien';
 $GLOBALS['__l10n']['one trackback'] = 'un rétrolien';
 $GLOBALS['__l10n']['%d trackbacks'] = '%d rétroliens';
-$GLOBALS['__l10n']['no attachment'] = 'aucune annexe';
+$GLOBALS['__l10n']['no attachments'] = 'aucune annexe';
 $GLOBALS['__l10n']['one attachment'] = 'une annexe';
 $GLOBALS['__l10n']['%d attachments'] = '%d annexes';
 $GLOBALS['__l10n']['previous entries'] = 'billets précédents';
@@ -91,5 +91,4 @@ $GLOBALS['__l10n']['You must give a password to access this area.'] = 'Vous deve
 $GLOBALS['__l10n']['Password:'] = 'Mot de passe :';
 $GLOBALS['__l10n']['You must provide a valid email address.'] = 'Vous devez indiquer une adresse e-mail valide.';
 $GLOBALS['__l10n']['Read'] = 'Lire';
-$GLOBALS['__l10n']['in'] = 'dans';
-$GLOBALS['__l10n']['In'] = 'Dans';
+$GLOBALS['__l10n']['Page top'] = 'Haut de page';
