@@ -18,7 +18,7 @@ $this->registerModule(
 	/* Version */			'1.1',
 	array(
 		'permissions' =>	'usage,contentadmin',
-		'priority' =>		200
+		'priority' =>		200,
+		'type'		=>		'plugin'
 	)
 );
-?>
\ No newline at end of file
