@@ -47,6 +47,10 @@ class dcFilterLinksLookup extends dcSpamFilter
 			$domain_elem = explode(".",$domain);
 
 			$i = count($domain_elem) - 1;
+			if ($i == 0) {
+				// "domain" is 1 word long, don't check it
+				return null;
+			}
 			$host = $domain_elem[$i];
 			do
 			{
