@@ -17,7 +17,7 @@ $this->registerModule(
 	/* Author */			"Olivier Meunier",
 	/* Version */			'1.2',
 	array(
-		'permissions' =>	'admin'
+		'permissions' =>	'admin',
+		'type'		=>		'plugin'
 	)
 );
-?>
\ No newline at end of file
