@@ -107,9 +107,9 @@ if (!empty($_POST))
 	try
 	{
 		$blowup_user['body_txt_f'] = $_POST['body_txt_f'];
-		$blowup_user['body_txt_s'] = blowupConfig::adjustFontSize($_POST['body_txt_s']);
-		$blowup_user['body_txt_c'] = blowupConfig::adjustColor($_POST['body_txt_c']);
-		$blowup_user['body_line_height'] = blowupConfig::adjustFontSize($_POST['body_line_height']);
+		$blowup_user['body_txt_s'] = dcThemeConfig::adjustFontSize($_POST['body_txt_s']);
+		$blowup_user['body_txt_c'] = dcThemeConfig::adjustColor($_POST['body_txt_c']);
+		$blowup_user['body_line_height'] = dcThemeConfig::adjustFontSize($_POST['body_line_height']);
 
 		$blowup_user['blog_title_hide'] = (integer) !empty($_POST['blog_title_hide']);
 		$update_blog_title = !$blowup_user['blog_title_hide'] && (
@@ -121,51 +121,51 @@ if (!empty($_POST))
 		if ($update_blog_title)
 		{
 			$blowup_user['blog_title_f'] = $_POST['blog_title_f'];
-			$blowup_user['blog_title_s'] = blowupConfig::adjustFontSize($_POST['blog_title_s']);
-			$blowup_user['blog_title_c'] = blowupConfig::adjustColor($_POST['blog_title_c']);
+			$blowup_user['blog_title_s'] = dcThemeConfig::adjustFontSize($_POST['blog_title_s']);
+			$blowup_user['blog_title_c'] = dcThemeConfig::adjustColor($_POST['blog_title_c']);
 			$blowup_user['blog_title_a'] = preg_match('/^(left|center|right)$/',$_POST['blog_title_a']) ? $_POST['blog_title_a'] : null;
-			$blowup_user['blog_title_p'] = blowupConfig::adjustPosition($_POST['blog_title_p']);
+			$blowup_user['blog_title_p'] = dcThemeConfig::adjustPosition($_POST['blog_title_p']);
 		}
 
-		$blowup_user['body_link_c'] = blowupConfig::adjustColor($_POST['body_link_c']);
-		$blowup_user['body_link_f_c'] = blowupConfig::adjustColor($_POST['body_link_f_c']);
-		$blowup_user['body_link_v_c'] = blowupConfig::adjustColor($_POST['body_link_v_c']);
+		$blowup_user['body_link_c'] = dcThemeConfig::adjustColor($_POST['body_link_c']);
+		$blowup_user['body_link_f_c'] = dcThemeConfig::adjustColor($_POST['body_link_f_c']);
+		$blowup_user['body_link_v_c'] = dcThemeConfig::adjustColor($_POST['body_link_v_c']);
 
 		$blowup_user['sidebar_text_f'] = $_POST['sidebar_text_f'];
-		$blowup_user['sidebar_text_s'] = blowupConfig::adjustFontSize($_POST['sidebar_text_s']);
-		$blowup_user['sidebar_text_c'] = blowupConfig::adjustColor($_POST['sidebar_text_c']);
+		$blowup_user['sidebar_text_s'] = dcThemeConfig::adjustFontSize($_POST['sidebar_text_s']);
+		$blowup_user['sidebar_text_c'] = dcThemeConfig::adjustColor($_POST['sidebar_text_c']);
 		$blowup_user['sidebar_title_f'] = $_POST['sidebar_title_f'];
-		$blowup_user['sidebar_title_s'] = blowupConfig::adjustFontSize($_POST['sidebar_title_s']);
-		$blowup_user['sidebar_title_c'] = blowupConfig::adjustColor($_POST['sidebar_title_c']);
+		$blowup_user['sidebar_title_s'] = dcThemeConfig::adjustFontSize($_POST['sidebar_title_s']);
+		$blowup_user['sidebar_title_c'] = dcThemeConfig::adjustColor($_POST['sidebar_title_c']);
 		$blowup_user['sidebar_title2_f'] = $_POST['sidebar_title2_f'];
-		$blowup_user['sidebar_title2_s'] = blowupConfig::adjustFontSize($_POST['sidebar_title2_s']);
-		$blowup_user['sidebar_title2_c'] = blowupConfig::adjustColor($_POST['sidebar_title2_c']);
-		$blowup_user['sidebar_line_c'] = blowupConfig::adjustColor($_POST['sidebar_line_c']);
-		$blowup_user['sidebar_link_c'] = blowupConfig::adjustColor($_POST['sidebar_link_c']);
-		$blowup_user['sidebar_link_f_c'] = blowupConfig::adjustColor($_POST['sidebar_link_f_c']);
-		$blowup_user['sidebar_link_v_c'] = blowupConfig::adjustColor($_POST['sidebar_link_v_c']);
+		$blowup_user['sidebar_title2_s'] = dcThemeConfig::adjustFontSize($_POST['sidebar_title2_s']);
+		$blowup_user['sidebar_title2_c'] = dcThemeConfig::adjustColor($_POST['sidebar_title2_c']);
+		$blowup_user['sidebar_line_c'] = dcThemeConfig::adjustColor($_POST['sidebar_line_c']);
+		$blowup_user['sidebar_link_c'] = dcThemeConfig::adjustColor($_POST['sidebar_link_c']);
+		$blowup_user['sidebar_link_f_c'] = dcThemeConfig::adjustColor($_POST['sidebar_link_f_c']);
+		$blowup_user['sidebar_link_v_c'] = dcThemeConfig::adjustColor($_POST['sidebar_link_v_c']);
 
 		$blowup_user['sidebar_position'] = ($_POST['sidebar_position'] == 'left') ? 'left' : null;
 
 		$blowup_user['date_title_f'] = $_POST['date_title_f'];
-		$blowup_user['date_title_s'] = blowupConfig::adjustFontSize($_POST['date_title_s']);
-		$blowup_user['date_title_c'] = blowupConfig::adjustColor($_POST['date_title_c']);
+		$blowup_user['date_title_s'] = dcThemeConfig::adjustFontSize($_POST['date_title_s']);
+		$blowup_user['date_title_c'] = dcThemeConfig::adjustColor($_POST['date_title_c']);
 
 		$blowup_user['post_title_f'] = $_POST['post_title_f'];
-		$blowup_user['post_title_s'] = blowupConfig::adjustFontSize($_POST['post_title_s']);
-		$blowup_user['post_title_c'] = blowupConfig::adjustColor($_POST['post_title_c']);
-		$blowup_user['post_comment_c'] = blowupConfig::adjustColor($_POST['post_comment_c']);
-		$blowup_user['post_commentmy_c'] = blowupConfig::adjustColor($_POST['post_commentmy_c']);
+		$blowup_user['post_title_s'] = dcThemeConfig::adjustFontSize($_POST['post_title_s']);
+		$blowup_user['post_title_c'] = dcThemeConfig::adjustColor($_POST['post_title_c']);
+		$blowup_user['post_comment_c'] = dcThemeConfig::adjustColor($_POST['post_comment_c']);
+		$blowup_user['post_commentmy_c'] = dcThemeConfig::adjustColor($_POST['post_commentmy_c']);
 
 
 		$blowup_user['footer_f'] = $_POST['footer_f'];
-		$blowup_user['footer_s'] = blowupConfig::adjustFontSize($_POST['footer_s']);
-		$blowup_user['footer_c'] = blowupConfig::adjustColor($_POST['footer_c']);
-		$blowup_user['footer_l_c'] = blowupConfig::adjustColor($_POST['footer_l_c']);
-		$blowup_user['footer_bg_c'] = blowupConfig::adjustColor($_POST['footer_bg_c']);
+		$blowup_user['footer_s'] = dcThemeConfig::adjustFontSize($_POST['footer_s']);
+		$blowup_user['footer_c'] = dcThemeConfig::adjustColor($_POST['footer_c']);
+		$blowup_user['footer_l_c'] = dcThemeConfig::adjustColor($_POST['footer_l_c']);
+		$blowup_user['footer_bg_c'] = dcThemeConfig::adjustColor($_POST['footer_bg_c']);
 
 
-		$blowup_user['extra_css'] = blowupConfig::cleanCSS($_POST['extra_css']);
+		$blowup_user['extra_css'] = dcThemeConfig::cleanCSS($_POST['extra_css']);
 
 		if ($can_write_images)
 		{
@@ -182,11 +182,11 @@ if (!empty($_POST))
 
 			$blowup_user['top_image'] = in_array($_POST['top_image'],$top_images) ? $_POST['top_image'] : 'default';
 
-			$blowup_user['body_bg_c'] = blowupConfig::adjustColor($_POST['body_bg_c']);
+			$blowup_user['body_bg_c'] = dcThemeConfig::adjustColor($_POST['body_bg_c']);
 			$blowup_user['body_bg_g'] = in_array($_POST['body_bg_g'],$gradient_types) ? $_POST['body_bg_g'] : '';
-			$blowup_user['post_comment_bg_c'] = blowupConfig::adjustColor($_POST['post_comment_bg_c']);
-			$blowup_user['post_commentmy_bg_c'] = blowupConfig::adjustColor($_POST['post_commentmy_bg_c']);
-			$blowup_user['prelude_c'] = blowupConfig::adjustColor($_POST['prelude_c']);
+			$blowup_user['post_comment_bg_c'] = dcThemeConfig::adjustColor($_POST['post_comment_bg_c']);
+			$blowup_user['post_commentmy_bg_c'] = dcThemeConfig::adjustColor($_POST['post_commentmy_bg_c']);
+			$blowup_user['prelude_c'] = dcThemeConfig::adjustColor($_POST['prelude_c']);
 			blowupConfig::createImages($blowup_user,$uploaded);
 		}
 
@@ -211,7 +211,7 @@ if (!empty($_POST))
 <html>
 <head>
   <title><?php echo __('Blowup configuration'); ?></title>
-  <?php echo dcPage::jsLoad('index.php?pf=blowupConfig/config.js'); ?>
+  <?php echo dcPage::jsLoad(dcPage::getPF('blowupConfig/config.js')); ?>
   <?php echo dcPage::jsColorPicker(); ?>
   <script type="text/javascript">
   //<![CDATA[
@@ -230,12 +230,12 @@ if (!empty($_POST))
 echo dcPage::breadcrumb(
 	array(
 		html::escapeHTML($core->blog->name) => '',
-		__('Blog appearance') => 'blog_theme.php',
+		__('Blog appearance') => $core->adminurl->get('admin.blog.theme'),
 		__('Blowup configuration') => ''
 	)).dcPage::notices();
 
 echo
-'<p><a class="back" href="blog_theme.php">'.__('Back to Blog appearance').'</a></p>';
+'<p><a class="back" href="'.$core->adminurl->get('admin.blog.theme').'">'.__('Back to Blog appearance').'</a></p>';
 
 
 if (!$can_write_images) {
@@ -311,7 +311,7 @@ if ($can_write_images) {
 	if ($blowup_user['top_image'] == 'custom' && $blowup_user['uploaded']) {
 		$preview_image = http::concatURL($core->blog->url,blowupConfig::imagesURL().'/page-t.png');
 	} else {
-		$preview_image = 'index.php?pf=blowupConfig/alpha-img/page-t/'.$blowup_user['top_image'].'.png';
+		$preview_image = dcPage::getPF('blowupConfig/alpha-img/page-t/'.$blowup_user['top_image'].'.png');
 	}
 
 	echo
