@@ -39,10 +39,11 @@ class pagesWidgets
 		);
 		$w->pages->setting('content_only',__('Content only'),0,'check');
 		$w->pages->setting('class',__('CSS class:'),'');
+		$w->pages->setting('offline',__('Offline'),0,'check');
 	}
 
 	public static function initDefaultWidgets($w,$d)
 	{
-		$d['extra']->append($w->pages);
+		$d['nav']->append($w->pages);
 	}
 }
