@@ -5,7 +5,7 @@
 				exec: function(editor) {
 					if (editor.getSelection().getNative().toString().replace(/\s*/,'')!='') {
 						var str = editor.getSelection().getNative().toString().replace(/\s*/,'');
-						var url = jsToolBar.prototype.elements.tag.url;
+						var url = dotclear.msg.tag_url;
 						window.dc_tag_editor.addMeta(str);
 						var link = '<a href="'+$.stripBaseURL(url+'/'+str)+'">'+str+'</a>';
 						var element = CKEDITOR.dom.element.createFromHtml(link);
@@ -15,7 +15,7 @@
 			});
 
 			editor.ui.addButton('dcTags', {
-				label: jsToolBar.prototype.elements.tag.title,
+				label: dotclear.msg.tag_title,
 				command: 'dcTagsCommand',
 				toolbar: 'insert',
 				icon: this.path + 'tag.png'
