@@ -1,6 +1,7 @@
 $(function() {
+	// Cope with saving
 	var msg = false;
-	$('#file-form input[name="write"]').click(function() {
+	$('#file-form input[name="write"]').click(function(e) {
 		var f = this.form;
 
 		var data = {
@@ -25,9 +26,20 @@ $(function() {
 				msg.text(dotclear.msg.document_saved);
 				$('#file-chooser').empty();
 				$(res).find('#file-chooser').children().appendTo('#file-chooser');
+
+				if ($.isFunction(confirmClosePage['getCurrentForms'])) {
+					confirmClosePage.forms = [];
+					confirmClosePage.getCurrentForms();
+				}
 			}
 		});
 
-		return false;
+		e.preventDefault();
 	});
+
+	// Confirm for deleting current file
+	$('#file-form input[name="delete"]').click(function() {
+		return window.confirm(dotclear.msg.confirm_reset_file);
+	});
+
 });
