@@ -26,13 +26,12 @@ if (isset($_POST['css']))
 	@$fp = fopen($css_file,'wb');
 	fwrite($fp,$_POST['css']);
 	fclose($fp);
-	
+
 	dcPage::message(__('Style sheet upgraded.'),true,true);
 }
 
 $css_content = is_file($css_file) ? file_get_contents($css_file) : '';
 
 echo
-'<p class="area"><label>'.__('Style sheet:').' '.
-form::textarea('css',60,20,html::escapeHTML($css_content)).'</label></p>';
-?>
\ No newline at end of file
+'<p class="area"><label>'.__('Style sheet:').'</label> '.
+form::textarea('css',60,20,html::escapeHTML($css_content)).'</p>';
