@@ -77,18 +77,6 @@ $webfont_apis = array(
 	__('stylesheet (Google)') => 'css'
 );
 
-function adjustFontSize($s)
-{
-	if (preg_match('/^([0-9.]+)\s*(%|pt|px|em|ex)?$/',$s,$m)) {
-		if (empty($m[2])) {
-			$m[2] = 'em';
-		}
-		return $m[1].$m[2];
-	}
-
-	return null;
-}
-
 $font_families = array(
 	// Theme standard
 	'Ductile body' => '"Century Schoolbook", "Century Schoolbook L", Georgia, serif',
@@ -118,117 +106,6 @@ function fontDef($c)
 	return isset($font_families[$c]) ? '<span style="position:absolute;top:0;left:32em;">'.$font_families[$c].'</span>' : '';
 }
 
-function adjustColor($c)
-{
-	if ($c === '') {
-		return '';
-	}
-
-	$c = strtoupper($c);
-
-	if (preg_match('/^[A-F0-9]{3,6}$/',$c)) {
-		$c = '#'.$c;
-	}
-
-	if (preg_match('/^#[A-F0-9]{6}$/',$c)) {
-		return $c;
-	}
-
-	if (preg_match('/^#[A-F0-9]{3,}$/',$c)) {
-		return '#'.substr($c,1,1).substr($c,1,1).substr($c,2,1).substr($c,2,1).substr($c,3,1).substr($c,3,1);
-	}
-
-	return '';
-}
-
-function computeContrastRatio($color,$background)
-{
-	// Compute contrast ratio between two colors
-
-	$color = adjustColor($color);
-	if (($color == '') || (strlen($color) != 7)) return 0;
-	$background = adjustColor($background);
-	if (($background == '') || (strlen($background) != 7)) return 0;
-
-	$l1 = (0.2126 * pow(hexdec(substr($color,1,2))/255,2.2)) +
-		(0.7152 * pow(hexdec(substr($color,3,2))/255,2.2)) +
-		(0.0722 * pow(hexdec(substr($color,5,2))/255,2.2));
-
-	$l2 = (0.2126 * pow(hexdec(substr($background,1,2))/255,2.2)) +
-	 	(0.7152 * pow(hexdec(substr($background,3,2))/255,2.2)) +
-		(0.0722 * pow(hexdec(substr($background,5,2))/255,2.2));
-
-	if ($l1 > $l2) {
-		$ratio = ($l1 + 0.05) / ($l2 + 0.05);
-	} else {
-		$ratio = ($l2 + 0.05) / ($l1 + 0.05);
-	}
-	return $ratio;
-}
-
-function contrastRatioLevel($ratio,$size,$bold)
-{
-	if ($size == '') {
-		return '';
-	}
-
-	// Eval font size in em (assume base font size in pixels equal to 16)
-	if (preg_match('/^([0-9.]+)\s*(%|pt|px|em|ex)?$/',$size,$m)) {
-		if (empty($m[2])) {
-			$m[2] = 'em';
-		}
-	} else {
-		return '';
-	}
-	switch ($m[2]) {
-		case '%':
-			$s = (float) $m[1] / 100;
-			break;
-		case 'pt':
-			$s = (float) $m[1] / 12;
-			break;
-		case 'px':
-			$s = (float) $m[1] / 16;
-			break;
-		case 'em':
-			$s = (float) $m[1];
-			break;
-		case 'ex':
-			$s = (float) $m[1] / 2;
-			break;
-		default:
-			return '';
-	}
-
-	$large = ((($s > 1.5) && ($bold == false)) || (($s > 1.2) && ($bold == true)));
-
-	// Check ratio
-	if ($ratio > 7) {
-		return 'AAA';
-	} elseif (($ratio > 4.5) && $large) {
-		return 'AAA';
-	} elseif ($ratio > 4.5) {
-		return 'AA';
-	} elseif (($ratio > 3) && $large) {
-		return 'AA';
-	}
-	return '';
-}
-
-function contrastRatio($color,$background,$size='',$bold=false)
-{
-	if (($color != '') && ($background != '')) {
-		$ratio = computeContrastRatio($color,$background);
-		$level = contrastRatioLevel($ratio,$size,$bold);
-		return
-			'<span style="position:absolute;top:0;left:23em;">'.
-			sprintf(__('ratio %.1f'),$ratio).
-			($level != '' ? ' '.sprintf(__('(%s)'),$level) : '').
-			'</span>';
-	}
-	return '';
-}
-
 $ductile_base = array(
 	// HTML
 	'subtitle_hidden' => null,
@@ -272,6 +149,7 @@ $ductile_lists_base = array(
 
 $ductile_counts_base = array(
 	'default' => null,
+	'default-page' => null,
 	'category' => null,
 	'tag' => null,
 	'search' => null
@@ -289,12 +167,14 @@ $ductile_lists = @unserialize($ductile_lists);
 if (!is_array($ductile_lists)) {
 	$ductile_lists = $ductile_lists_base;
 }
+$ductile_lists = array_merge($ductile_lists_base,$ductile_lists);
 
 $ductile_counts = $core->blog->settings->themes->get($core->blog->settings->system->theme.'_entries_counts');
 $ductile_counts = @unserialize($ductile_counts);
 if (!is_array($ductile_counts)) {
 	$ductile_counts = $ductile_counts_base;
 }
+$ductile_counts = array_merge($ductile_counts_base,$ductile_counts);
 
 $ductile_stickers = $core->blog->settings->themes->get($core->blog->settings->system->theme.'_stickers');
 $ductile_stickers = @unserialize($ductile_stickers);
@@ -394,26 +274,26 @@ if (!empty($_POST))
 			$ductile_user['alternate_webfont_api'] = $_POST['alternate_webfont_api'];
 
 			$ductile_user['blog_title_w'] = (integer) !empty($_POST['blog_title_w']);
-			$ductile_user['blog_title_s'] = adjustFontSize($_POST['blog_title_s']);
-			$ductile_user['blog_title_c'] = adjustColor($_POST['blog_title_c']);
+			$ductile_user['blog_title_s'] = dcThemeConfig::adjustFontSize($_POST['blog_title_s']);
+			$ductile_user['blog_title_c'] = dcThemeConfig::adjustColor($_POST['blog_title_c']);
 
 			$ductile_user['post_title_w'] = (integer) !empty($_POST['post_title_w']);
-			$ductile_user['post_title_s'] = adjustFontSize($_POST['post_title_s']);
-			$ductile_user['post_title_c'] = adjustColor($_POST['post_title_c']);
+			$ductile_user['post_title_s'] = dcThemeConfig::adjustFontSize($_POST['post_title_s']);
+			$ductile_user['post_title_c'] = dcThemeConfig::adjustColor($_POST['post_title_c']);
 
 			$ductile_user['post_link_w'] = (integer) !empty($_POST['post_link_w']);
-			$ductile_user['post_link_v_c'] = adjustColor($_POST['post_link_v_c']);
-			$ductile_user['post_link_f_c'] = adjustColor($_POST['post_link_f_c']);
+			$ductile_user['post_link_v_c'] = dcThemeConfig::adjustColor($_POST['post_link_v_c']);
+			$ductile_user['post_link_f_c'] = dcThemeConfig::adjustColor($_POST['post_link_f_c']);
 
-			$ductile_user['post_simple_title_c'] = adjustColor($_POST['post_simple_title_c']);
+			$ductile_user['post_simple_title_c'] = dcThemeConfig::adjustColor($_POST['post_simple_title_c']);
 
 			$ductile_user['blog_title_w_m'] = (integer) !empty($_POST['blog_title_w_m']);
-			$ductile_user['blog_title_s_m'] = adjustFontSize($_POST['blog_title_s_m']);
-			$ductile_user['blog_title_c_m'] = adjustColor($_POST['blog_title_c_m']);
+			$ductile_user['blog_title_s_m'] = dcThemeConfig::adjustFontSize($_POST['blog_title_s_m']);
+			$ductile_user['blog_title_c_m'] = dcThemeConfig::adjustColor($_POST['blog_title_c_m']);
 
 			$ductile_user['post_title_w_m'] = (integer) !empty($_POST['post_title_w_m']);
-			$ductile_user['post_title_s_m'] = adjustFontSize($_POST['post_title_s_m']);
-			$ductile_user['post_title_c_m'] = adjustColor($_POST['post_title_c_m']);
+			$ductile_user['post_title_s_m'] = dcThemeConfig::adjustFontSize($_POST['post_title_s_m']);
+			$ductile_user['post_title_c_m'] = dcThemeConfig::adjustColor($_POST['post_title_c_m']);
 		}
 
 		$core->blog->settings->addNamespace('themes');
@@ -444,7 +324,8 @@ if (!$standalone_config) echo '</form>';
 echo '<div class="multi-part" id="themes-list'.($conf_tab == 'html' ? '' : '-html').'" title="'.__('Content').'">'.
 '<h3>'.__('Content').'</h3>';
 
-echo '<form id="theme_config" action="blog_theme.php?conf=1" method="post" enctype="multipart/form-data">';
+echo '<form id="theme_config" action="'.$core->adminurl->get('admin.blog.theme',array('conf' => '1')).
+'" method="post" enctype="multipart/form-data">';
 
 echo '<h4>'.__('Header').'</h4>'.
 '<p class="field"><label for="subtitle_hidden">'.__('Hide blog description:').'</label> '.
@@ -453,7 +334,8 @@ echo '<p class="field"><label for="logo_src">'.__('Logo URL:').'</label> '.
 	form::field('logo_src',40,255,$ductile_user['logo_src']).'</p>';
 if ($core->plugins->moduleExists('simpleMenu'))
 {
-	echo '<p>'.sprintf(__('To configure the top menu go to the <a href="%s">Simple Menu administration page</a>.'),'plugin.php?p=simpleMenu').'</p>';
+	echo '<p>'.sprintf(__('To configure the top menu go to the <a href="%s">Simple Menu administration page</a>.'),
+		$core->adminurl->get('admin.plugin.simpleMenu')).'</p>';
 }
 
 echo '<h4 class="border-top pretty-title">'.__('Stickers').'</h4>';
@@ -528,7 +410,8 @@ echo '</div>'; // Close tab
 
 echo '<div class="multi-part" id="themes-list'.($conf_tab == 'css' ? '' : '-css').'" title="'.__('Presentation').'">';
 
-echo '<form id="theme_config" action="blog_theme.php?conf=1" method="post" enctype="multipart/form-data">';
+echo '<form id="theme_config" action="'.$core->adminurl->get('admin.blog.theme',array('conf' => '1')).
+	'" method="post" enctype="multipart/form-data">';
 
 echo '<h3>'.__('General settings').'</h3>';
 
@@ -579,7 +462,7 @@ form::field('blog_title_s',7,7,$ductile_user['blog_title_s']).'</p>'.
 
 '<p class="field picker"><label for="blog_title_c">'.__('Color:').'</label> '.
 form::field('blog_title_c',7,7,$ductile_user['blog_title_c'],'colorpicker').
-contrastRatio($ductile_user['blog_title_c'],'#ffffff',
+dcThemeConfig::contrastRatio($ductile_user['blog_title_c'],'#ffffff',
 	(!empty($ductile_user['blog_title_s']) ? $ductile_user['blog_title_s'] : '2em'),
 	$ductile_user['blog_title_w']).
 '</p>';
@@ -596,7 +479,7 @@ form::field('post_title_s',7,7,$ductile_user['post_title_s']).'</p>'.
 
 '<p class="field picker"><label for="post_title_c">'.__('Color:').'</label> '.
 form::field('post_title_c',7,7,$ductile_user['post_title_c'],'colorpicker').
-contrastRatio($ductile_user['post_title_c'],'#ffffff',
+dcThemeConfig::contrastRatio($ductile_user['post_title_c'],'#ffffff',
 	(!empty($ductile_user['post_title_s']) ? $ductile_user['post_title_s'] : '2.5em'),
 	$ductile_user['post_title_w']).
 '</p>';
@@ -608,7 +491,7 @@ echo '<h5>'.__('Titles without link').'</h5>'.
 
 '<p class="field picker"><label for="post_simple_title_c">'.__('Color:').'</label> '.
 form::field('post_simple_title_c',7,7,$ductile_user['post_simple_title_c'],'colorpicker').
-contrastRatio($ductile_user['post_simple_title_c'],'#ffffff',
+dcThemeConfig::contrastRatio($ductile_user['post_simple_title_c'],'#ffffff',
 	'1.1em',	// H5 minimum size
 	false).
 '</p>';
@@ -619,14 +502,14 @@ form::checkbox('post_link_w',1,$ductile_user['post_link_w']).'</p>'.
 
 '<p class="field picker"><label for="post_link_v_c">'.__('Normal and visited links color:').'</label> '.
 form::field('post_link_v_c',7,7,$ductile_user['post_link_v_c'],'colorpicker').
-contrastRatio($ductile_user['post_link_v_c'],'#ffffff',
+dcThemeConfig::contrastRatio($ductile_user['post_link_v_c'],'#ffffff',
 	'1em',
 	$ductile_user['post_link_w']).
 '</p>'.
 
 '<p class="field picker"><label for="post_link_f_c">'.__('Active, hover and focus links color:').'</label> '.
 form::field('post_link_f_c',7,7,$ductile_user['post_link_f_c'],'colorpicker').
-contrastRatio($ductile_user['post_link_f_c'],'#ebebee',
+dcThemeConfig::contrastRatio($ductile_user['post_link_f_c'],'#ebebee',
 	'1em',
 	$ductile_user['post_link_w']).
 '</p>';
@@ -645,7 +528,7 @@ form::field('blog_title_s_m',7,7,$ductile_user['blog_title_s_m']).'</p>'.
 
 '<p class="field picker"><label for="blog_title_c_m">'.__('Color:').'</label> '.
 form::field('blog_title_c_m',7,7,$ductile_user['blog_title_c_m'],'colorpicker').
-contrastRatio($ductile_user['blog_title_c_m'],'#d7d7dc',
+dcThemeConfig::contrastRatio($ductile_user['blog_title_c_m'],'#d7d7dc',
 	(!empty($ductile_user['blog_title_s_m']) ? $ductile_user['blog_title_s_m'] : '1.8em'),
 	$ductile_user['blog_title_w_m']).
 '</p>';
@@ -662,7 +545,7 @@ form::field('post_title_s_m',7,7,$ductile_user['post_title_s_m']).'</p>'.
 
 '<p class="field picker"><label for="post_title_c_m">'.__('Color:').'</label> '.
 form::field('post_title_c_m',7,7,$ductile_user['post_title_c_m'],'colorpicker').
-contrastRatio($ductile_user['post_title_c_m'],'#ffffff',
+dcThemeConfig::contrastRatio($ductile_user['post_title_c_m'],'#ffffff',
 	(!empty($ductile_user['post_title_s_m']) ? $ductile_user['post_title_s_m'] : '1.5em'),
 	$ductile_user['post_title_w_m']).
 '</p>';
